"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QTextLayout(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextlayout.html

    **Detailed Description**

    It offers many features expected from a modern text layout engine, including
    Unicode compliant rendering, line breaking and handling of cursor
    positioning. It can also produce and render device independent layout,
    something that is important for WYSIWYG applications.

    The class has a rather low level API and unless you intend to implement your
    own text rendering for some specialized widget, you probably won't need to
    use it directly.

    QTextLayout can be used with both plain and rich text.

    QTextLayout can be used to create a sequence of **QTextLine**  instances
    with given widths and can position them independently on the screen. Once
    the layout is done, these lines can be drawn on a paint device.

    The text to be laid out can be provided in the constructor or set with
    **setText** ().

    The layout can be seen as a sequence of **QTextLine**  objects; use
    **createLine** () to create a **QTextLine**  instance, and **lineAt** () or
    **lineForTextPosition** () to retrieve created lines.

    Here is a code snippet that demonstrates the layout phase:

    int leading = fontMetrics.leading();
        **qreal**  height = 0;
    textLayout.setCacheEnabled(true);
        textLayout.beginLayout();
        while
    (1) {
            **QTextLine**  line = textLayout.createLine();
            if
    (!line.isValid())
                break;
    line.setLineWidth(lineWidth);
            height += leading;
    line.setPosition(**QPointF** (0, height));
            height += line.height();
    }
        textLayout.endLayout();

    The text can then be rendered by calling the layout's **draw** () function:

    **QPainter**  painter(this);
        textLayout.draw(&painter, **QPoint** (0,
    0));

    For a given position in the text you can find a valid cursor position with
    **isValidCursorPosition** (), **nextCursorPosition** (), and
    **previousCursorPosition** ().

    The QTextLayout itself can be positioned with **setPosition** (); it has a
    **boundingRect** (), and a **minimumWidth** () and a **maximumWidth** ().

    **See also** **QStaticText** .
    """

    class CursorMode(enum.Enum):
        SkipCharacters: QTextLayout = ...
        SkipWords: QTextLayout = ...

    class FormatRange(PyQt6.sip.simplewrapper):
        format: QTextCharFormat = ...
        length: int = ...
        start: int = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QTextLayout.FormatRange") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#QTextLayout

        **QTextLayout::QTextLayout()**

        Constructs an empty text layout.

        **See also** **setText** ().
        """
        ...

    @typing.overload
    def __init__(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#QTextLayout-1

        **QTextLayout::QTextLayout(const QString & text )**

        Constructs a text layout to lay out the given **text**.
        """
        ...

    @typing.overload
    def __init__(
        self, text: str, font: QFont, paintdevice: typing.Optional[QPaintDevice] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#QTextLayout-2

        **[since 5.13] QTextLayout::QTextLayout(const QString & text , const
        QFont & font , const QPaintDevice * paintdevice = nullptr)**

        Constructs a text layout to lay out the given **text** with the
        specified **font**.

        All the metric and layout calculations will be done in terms of the
        paint device, **paintdevice**. If **paintdevice** is `nullptr` the
        calculations will be done in screen metrics.

        This function was introduced in Qt 5.13.
        """
        ...

    @typing.overload
    def __init__(self, b: "QTextBlock") -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#QTextLayout

        **QTextLayout::QTextLayout()**

        Constructs an empty text layout.

        **See also** **setText** ().
        """
        ...

    def clearFormats(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#clearFormats

        **[since 5.6] void QTextLayout::clearFormats()**

        Clears the list of additional formats supported by the text layout.

        This function was introduced in Qt 5.6.

        **See also** **formats** () and **setFormats** ().
        """
        ...

    def formats(self) -> typing.List["QTextLayout.FormatRange"]:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#formats

        **[since 5.6] QList<QTextLayout::FormatRange> QTextLayout::formats()
        const**

        Returns the list of additional formats supported by the text layout.

        This function was introduced in Qt 5.6.

        **See also** **setFormats** () and **clearFormats** ().
        """
        ...

    def setFormats(self, overrides: typing.Iterable["QTextLayout.FormatRange"]) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#setFormats

        **[since 5.6] void QTextLayout::setFormats(const
        QList<QTextLayout::FormatRange> & formats )**

        Sets the additional formats supported by the text layout to **formats**.
        The formats are applied with preedit area text in place.

        This function was introduced in Qt 5.6.

        **See also** **formats** () and **clearFormats** ().
        """
        ...

    def glyphRuns(self, from_: int = ..., length: int = ...) -> typing.List[QGlyphRun]:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#glyphRuns

        **QList<QGlyphRun> QTextLayout::glyphRuns(int from = -1, int length =
        -1) const**

        Returns the glyph indexes and positions for all glyphs corresponding to
        the **length** characters starting at the position **from** in this
        **QTextLayout** . This is an expensive function, and should not be
        called in a time sensitive context.

        If **from** is less than zero, then the glyph run will begin at the
        first character in the layout. If **length** is less than zero, it will
        span the entire string from the start position.

        **See also** **draw** () and **QPainter::drawGlyphRun** ().
        """
        ...

    def rightCursorPosition(self, oldPos: int) -> int:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#rightCursorPosition

        **int QTextLayout::rightCursorPosition(int oldPos ) const**

        Returns the cursor position to the right of **oldPos** , next to it.
        It's dependent on the visual position of characters, after bi-
        directional reordering.

        **See also** **leftCursorPosition** () and **nextCursorPosition** ().
        """
        ...

    def leftCursorPosition(self, oldPos: int) -> int:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#leftCursorPosition

        **int QTextLayout::leftCursorPosition(int oldPos ) const**

        Returns the cursor position to the left of **oldPos** , next to it. It's
        dependent on the visual position of characters, after bi-directional
        reordering.

        **See also** **rightCursorPosition** () and **previousCursorPosition**
        ().
        """
        ...

    def cursorMoveStyle(self) -> QtCore.Qt.CursorMoveStyle:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#cursorMoveStyle

        **Qt::CursorMoveStyle QTextLayout::cursorMoveStyle() const**

        The cursor movement style of this **QTextLayout** . The default is
        **Qt::LogicalMoveStyle** .

        **See also** **setCursorMoveStyle** ().
        """
        ...

    def setCursorMoveStyle(self, style: QtCore.Qt.CursorMoveStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#setCursorMoveStyle

        **void QTextLayout::setCursorMoveStyle(Qt::CursorMoveStyle style )**

        Sets the visual cursor movement style to the given **style**. If the
        **QTextLayout**  is backed by a document, you can ignore this and use
        the option in **QTextDocument** , this option is for widgets like
        **QLineEdit**  or custom widgets without a **QTextDocument** . Default
        value is **Qt::LogicalMoveStyle** .

        **See also** **cursorMoveStyle** ().
        """
        ...

    def clearLayout(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#clearLayout

        **void QTextLayout::clearLayout()**

        Clears the line information in the layout. After having called this
        function, **lineCount** () returns 0.

        **Warning:** This will invalidate the layout, so all existing
        **QTextLine**  objects that refer to the previous contents should now be
        discarded.
        """
        ...

    def maximumWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#maximumWidth

        **qreal QTextLayout::maximumWidth() const**

        The maximum width the layout could expand to; this is essentially the
        width of the entire text.

        **Warning:** This function only returns a valid value after the layout
        has been done.

        **See also** **minimumWidth** ().
        """
        ...

    def minimumWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#minimumWidth

        **qreal QTextLayout::minimumWidth() const**

        The minimum width the layout needs. This is the width of the layout's
        smallest non-breakable substring.

        **Warning:** This function only returns a valid value after the layout
        has been done.

        **See also** **maximumWidth** ().
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#boundingRect

        **QRectF QTextLayout::boundingRect() const**

        The smallest rectangle that contains all the lines in the layout.
        """
        ...

    def setPosition(self, p: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#setPosition

        **void QTextLayout::setPosition(const QPointF & p )**

        Moves the text layout to point **p**.

        **See also** **position** ().
        """
        ...

    def position(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#position

        **QPointF QTextLayout::position() const**

        The global position of the layout. This is independent of the bounding
        rectangle and of the layout process.

        **See also** **setPosition** ().
        """
        ...

    @typing.overload
    def drawCursor(self, p: QPainter, pos: QtCore.QPointF, cursorPosition: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#drawCursor

        **void QTextLayout::drawCursor(QPainter * painter , const QPointF &
        position , int cursorPosition , int width ) const**

        Draws a text cursor with the current pen and the specified **width** at
        the given **position** using the **painter** specified. The
        corresponding position within the text is specified by
        **cursorPosition**.
        """
        ...

    @typing.overload
    def drawCursor(
        self, p: QPainter, pos: QtCore.QPointF, cursorPosition: int, width: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#drawCursor-1

        **void QTextLayout::drawCursor(QPainter * painter , const QPointF &
        position , int cursorPosition ) const**

        This is an overloaded function.

        Draws a text cursor with the current pen at the given **position** using
        the **painter** specified. The corresponding position within the text is
        specified by **cursorPosition**.
        """
        ...

    def draw(
        self,
        p: QPainter,
        pos: QtCore.QPointF,
        selections: typing.Iterable["QTextLayout.FormatRange"] = ...,
        clip: QtCore.QRectF = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#draw

        **void QTextLayout::draw(QPainter * p , const QPointF & pos , const
        QList<QTextLayout::FormatRange> & selections = QList<FormatRange>(),
        const QRectF & clip = QRectF()) const**

        Draws the whole layout on the painter **p** at the position specified by
        **pos**. The rendered layout includes the given **selections** and is
        clipped within the rectangle specified by **clip**.
        """
        ...

    def previousCursorPosition(
        self, oldPos: int, mode: "QTextLayout.CursorMode" = ...
    ) -> int:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#previousCursorPosition

        **int QTextLayout::previousCursorPosition(int oldPos ,
        QTextLayout::CursorMode mode = SkipCharacters) const**

        Returns the first valid cursor position before **oldPos** that respects
        the given cursor **mode**. Returns value of **oldPos** , if **oldPos**
        is not a valid cursor position.

        **See also** **isValidCursorPosition** () and **nextCursorPosition** ().
        """
        ...

    def nextCursorPosition(
        self, oldPos: int, mode: "QTextLayout.CursorMode" = ...
    ) -> int:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#nextCursorPosition

        **int QTextLayout::nextCursorPosition(int oldPos ,
        QTextLayout::CursorMode mode = SkipCharacters) const**

        Returns the next valid cursor position after **oldPos** that respects
        the given cursor **mode**. Returns value of **oldPos** , if **oldPos**
        is not a valid cursor position.

        **See also** **isValidCursorPosition** () and **previousCursorPosition**
        ().
        """
        ...

    def isValidCursorPosition(self, pos: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#isValidCursorPosition

        **bool QTextLayout::isValidCursorPosition(int pos ) const**

        / Returns `true` if position **pos** is a valid cursor position.

        In a Unicode context some positions in the text are not valid cursor
        positions, because the position is inside a Unicode surrogate or a
        grapheme cluster.

        A grapheme cluster is a sequence of two or more Unicode characters that
        form one indivisible entity on the screen. For example the latin
        character `Ä' can be represented in Unicode by two characters, `A'
        (0x41), and the combining diaeresis (0x308). A text cursor can only
        validly be positioned before or after these two characters, never
        between them since that wouldn't make sense. In indic languages every
        syllable forms a grapheme cluster.
        """
        ...

    def lineForTextPosition(self, pos: int) -> "QTextLine":
        """
        https://doc.qt.io/qt-6/qtextlayout.html#lineForTextPosition

        **QTextLine QTextLayout::lineForTextPosition(int pos ) const**

        Returns the line that contains the cursor position specified by **pos**.

        **See also** **isValidCursorPosition** () and **lineAt** ().
        """
        ...

    def lineAt(self, i: int) -> "QTextLine":
        """
        https://doc.qt.io/qt-6/qtextlayout.html#lineAt

        **QTextLine QTextLayout::lineAt(int i ) const**

        Returns the **i** -th line of text in this text layout.

        **See also** **lineCount** () and **lineForTextPosition** ().
        """
        ...

    def lineCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#lineCount

        **int QTextLayout::lineCount() const**

        Returns the number of lines in this text layout.

        **See also** **lineAt** ().
        """
        ...

    def createLine(self) -> "QTextLine":
        """
        https://doc.qt.io/qt-6/qtextlayout.html#createLine

        **QTextLine QTextLayout::createLine()**

        Returns a new text line to be laid out if there is text to be inserted
        into the layout; otherwise returns an invalid text line.

        The text layout creates a new line object that starts after the last
        line in the layout, or at the beginning if the layout is empty. The
        layout maintains an internal cursor, and each line is filled with text
        from the cursor position onwards when the **QTextLine::setLineWidth** ()
        function is called.

        Once **QTextLine::setLineWidth** () is called, a new line can be created
        and filled with text. Repeating this process will lay out the whole
        block of text contained in the **QTextLayout** . If there is no text
        left to be inserted into the layout, the **QTextLine**  returned will
        not be valid (isValid() will return false).
        """
        ...

    def endLayout(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#endLayout

        **void QTextLayout::endLayout()**

        Ends the layout process.

        **See also** **beginLayout** ().
        """
        ...

    def beginLayout(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#beginLayout

        **void QTextLayout::beginLayout()**

        Begins the layout process.

        **Warning:** This will invalidate the layout, so all existing
        **QTextLine**  objects that refer to the previous contents should now be
        discarded.

        **See also** **endLayout** ().
        """
        ...

    def cacheEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#cacheEnabled

        **bool QTextLayout::cacheEnabled() const**

        Returns `true` if the complete layout information is cached; otherwise
        returns `false`.

        **See also** **setCacheEnabled** ().
        """
        ...

    def setCacheEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#setCacheEnabled

        **void QTextLayout::setCacheEnabled(bool enable )**

        Enables caching of the complete layout information if **enable** is
        true; otherwise disables layout caching. Usually **QTextLayout**  throws
        most of the layouting information away after a call to **endLayout** ()
        to reduce memory consumption. If you however want to draw the laid out
        text directly afterwards enabling caching might speed up drawing
        significantly.

        **See also** **cacheEnabled** ().
        """
        ...

    def preeditAreaText(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#preeditAreaText

        **QString QTextLayout::preeditAreaText() const**

        Returns the text that is inserted in the layout before editing occurs.

        **See also** **preeditAreaPosition** ().
        """
        ...

    def preeditAreaPosition(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#preeditAreaPosition

        **int QTextLayout::preeditAreaPosition() const**

        Returns the position of the area in the text layout that will be
        processed before editing occurs.

        **See also** **preeditAreaText** ().
        """
        ...

    def setPreeditArea(self, position: int, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#setPreeditArea

        **void QTextLayout::setPreeditArea(int position , const QString & text
        )**

        Sets the **position** and **text** of the area in the layout that is
        processed before editing occurs. The layout is invalidated and must be
        laid out again.

        **See also** **preeditAreaPosition** () and **preeditAreaText** ().
        """
        ...

    def textOption(self) -> "QTextOption":
        """
        https://doc.qt.io/qt-6/qtextlayout.html#textOption

        **const QTextOption &QTextLayout::textOption() const**

        Returns the current text option used to control the layout process.

        **See also** **setTextOption** ().
        """
        ...

    def setTextOption(self, option: "QTextOption") -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#setTextOption

        **void QTextLayout::setTextOption(const QTextOption & option )**

        Sets the text option structure that controls the layout process to the
        given **option**.

        **See also** **textOption** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#text

        **QString QTextLayout::text() const**

        Returns the layout's text.

        **See also** **setText** ().
        """
        ...

    def setText(self, string: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#setText

        **void QTextLayout::setText(const QString & string )**

        Sets the layout's text to the given **string**. The layout is
        invalidated and must be laid out again.

        Notice that when using this **QTextLayout**  as part of a
        **QTextDocument**  this method will have no effect.

        **See also** **text** ().
        """
        ...

    def font(self) -> QFont:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#font

        **QFont QTextLayout::font() const**

        Returns the current font that is used for the layout, or a default font
        if none is set.

        **See also** **setFont** ().
        """
        ...

    def setFont(self, f: QFont) -> None:
        """
        https://doc.qt.io/qt-6/qtextlayout.html#setFont

        **void QTextLayout::setFont(const QFont & font )**

        Sets the layout's font to the given **font**. The layout is invalidated
        and must be laid out again.

        **See also** **font** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QStandardPaths(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qstandardpaths.html

    **Detailed Description**

    This class contains functions to query standard locations on the local
    filesystem, for common tasks such as user-specific directories or system-
    wide configuration directories.
    """

    class LocateOption(enum.Flag):
        LocateFile: QStandardPaths = ...
        LocateDirectory: QStandardPaths = ...

    class StandardLocation(enum.Enum):
        DesktopLocation: QStandardPaths = ...
        DocumentsLocation: QStandardPaths = ...
        FontsLocation: QStandardPaths = ...
        ApplicationsLocation: QStandardPaths = ...
        MusicLocation: QStandardPaths = ...
        MoviesLocation: QStandardPaths = ...
        PicturesLocation: QStandardPaths = ...
        TempLocation: QStandardPaths = ...
        HomeLocation: QStandardPaths = ...
        CacheLocation: QStandardPaths = ...
        GenericDataLocation: QStandardPaths = ...
        RuntimeLocation: QStandardPaths = ...
        ConfigLocation: QStandardPaths = ...
        DownloadLocation: QStandardPaths = ...
        GenericCacheLocation: QStandardPaths = ...
        GenericConfigLocation: QStandardPaths = ...
        AppDataLocation: QStandardPaths = ...
        AppLocalDataLocation: QStandardPaths = ...
        AppConfigLocation: QStandardPaths = ...

    def __init__(self, a0: "QStandardPaths") -> None:
        ...

    @staticmethod
    def setTestModeEnabled(testMode: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstandardpaths.html#setTestModeEnabled

        **[static] void QStandardPaths::setTestModeEnabled(bool testMode )**

        If **testMode** is `true`, this enables a special "test mode" in
        **QStandardPaths** , which changes writable locations to point to test
        directories. This prevents auto tests from reading or writing to the
        current user's configuration.

        It affects the locations into which test programs might write files:
        `GenericDataLocation`, `AppDataLocation`, `ConfigLocation`,
        `GenericConfigLocation`, `AppConfigLocation`, `GenericCacheLocation`,
        and `CacheLocation`. Other locations are not affected.

        On Unix, `XDG_DATA_HOME` is set to `~/.qttest/share`, `XDG_CONFIG_HOME`
        is set to `~/.qttest/config`, and `XDG_CACHE_HOME` is set to
        `~/.qttest/cache`.

        On macOS, data goes to `~/.qttest/Application Support`, cache goes to
        `~/.qttest/Cache`, and config goes to `~/.qttest/Preferences`.

        On Windows, everything goes to a "qttest" directory under `%APPDATA%`.
        """
        ...

    @staticmethod
    def findExecutable(executableName: str, paths: typing.Iterable[str] = ...) -> str:
        """
        https://doc.qt.io/qt-6/qstandardpaths.html#findExecutable

        **[static] QString QStandardPaths::findExecutable(const QString &
        executableName , const QStringList & paths = QStringList())**

        Finds the executable named **executableName** in the specified **paths**
        , or the system paths if paths is empty.

        On most operating systems the system path is determined by the `PATH`
        environment variable. The directories where to search for the executable
        can be set in the paths argument. To search in both your own paths and
        the system paths, call findExecutable twice, once with paths set and
        once with paths empty. Symlinks are not resolved in order to preserve
        behavior for the case of executables whose behavior depends on the name
        they are invoked with .

        **Note:** On Windows, the usual executable extensions (from the PATHEXT
        environment variable) are automatically appended. For example, the
        findExecutable("foo") call finds `foo.exe` or `foo.bat` if present.

        Returns the absolute file path to the executable, or an empty string if
        not found.
        """
        ...

    @staticmethod
    def displayName(type: "QStandardPaths.StandardLocation") -> str:
        """
        https://doc.qt.io/qt-6/qstandardpaths.html#displayName

        **[static] QString
        QStandardPaths::displayName(QStandardPaths::StandardLocation type )**

        Returns a localized display name for the given location **type** or an
        empty **QString**  if no relevant location can be found.
        """
        ...

    @staticmethod
    def locateAll(
        type: "QStandardPaths.StandardLocation",
        fileName: str,
        options: "QStandardPaths.LocateOption" = ...,
    ) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qstandardpaths.html#locateAll

        **[static] QStringList
        QStandardPaths::locateAll(QStandardPaths::StandardLocation type , const
        QString & fileName , QStandardPaths::LocateOptions options =
        LocateFile)**

        Finds all files or directories by the name, **fileName** , in the
        standard locations for **type**.

        The **options** flag lets you specify whether to look for files or
        directories. By default, this flag is set to `LocateFile`.

        Returns the list of all the files that were found.
        """
        ...

    @staticmethod
    def locate(
        type: "QStandardPaths.StandardLocation",
        fileName: str,
        options: "QStandardPaths.LocateOption" = ...,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qstandardpaths.html#locate

        **[static] QString
        QStandardPaths::locate(QStandardPaths::StandardLocation type , const
        QString & fileName , QStandardPaths::LocateOptions options =
        LocateFile)**

        Finds a file or directory called **fileName** in the standard locations
        for **type**.

        The **options** flag lets you specify whether to look for files or
        directories. By default, this flag is set to `LocateFile`.

        Returns the absolute path to the first file or directory found,
        otherwise returns an empty string.
        """
        ...

    @staticmethod
    def standardLocations(type: "QStandardPaths.StandardLocation") -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qstandardpaths.html#standardLocations

        **[static] QStringList
        QStandardPaths::standardLocations(QStandardPaths::StandardLocation type
        )**

        Returns all the directories where files of **type** belong.

        The list of directories is sorted from high to low priority, starting
        with **writableLocation** () if it can be determined. This list is empty
        if no locations for type are defined.

        **See also** **writableLocation** ().
        """
        ...

    @staticmethod
    def writableLocation(type: "QStandardPaths.StandardLocation") -> str:
        """
        https://doc.qt.io/qt-6/qstandardpaths.html#writableLocation

        **[static] QString
        QStandardPaths::writableLocation(QStandardPaths::StandardLocation type
        )**

        Returns the directory where files of **type** should be written to, or
        an empty string if the location cannot be determined.

        **Note:** The storage location returned may not exist; that is, it may
        need to be created by the system or the user.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QHoverEvent(QSinglePointEvent):
    """
    https://doc.qt.io/qt-6/qhoverevent.html

    **Detailed Description**

    Mouse events occur when a mouse cursor is moved into, out of, or within a
    widget, and if the widget has the **Qt::WA_Hover**  attribute.

    The function pos() gives the current cursor position, while **oldPos** ()
    gives the old mouse position.

    There are a few similarities between the events **QEvent::HoverEnter**  and
    **QEvent::HoverLeave** , and the events **QEvent::Enter**  and
    **QEvent::Leave** . However, they are slightly different because we do an
    update() in the event handler of HoverEnter and HoverLeave.

    **QEvent::HoverMove**  is also slightly different from **QEvent::MouseMove**
    . Let us consider a top-level window A containing a child B which in turn
    contains a child C (all with mouse tracking enabled):

    ![](images/hoverevents.png)

    Now, if you move the cursor from the top to the bottom in the middle of A,
    you will get the following **QEvent::MouseMove**  events:

    1. A::MouseMove
      2. B::MouseMove
      3. C::MouseMove

    You will get the same events for **QEvent::HoverMove** , except that the
    event always propagates to the top-level regardless whether the event is
    accepted or not. It will only stop propagating with the
    **Qt::WA_NoMousePropagation**  attribute.

    In this case the events will occur in the following way:

    1. A::HoverMove
      2. A::HoverMove, B::HoverMove
      3. A::HoverMove,
    B::HoverMove, C::HoverMove
    """

    def __init__(
        self,
        type: QtCore.QEvent.Type,
        pos: QtCore.QPointF,
        oldPos: QtCore.QPointF,
        modifiers: QtCore.Qt.KeyboardModifier = ...,
        device: typing.Optional["QPointingDevice"] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhoverevent.html#QHoverEvent-2

        **QHoverEvent::QHoverEvent(QEvent::Type type , const QPointF & pos ,
        const QPointF & oldPos , Qt::KeyboardModifiers modifiers =
        Qt::NoModifier, const QPointingDevice * device =
        QPointingDevice::primaryPointingDevice())**

        Constructs a hover event object originating from **device**.

        The **type** parameter must be **QEvent::HoverEnter** ,
        **QEvent::HoverLeave** , or **QEvent::HoverMove** .

        The **pos** is the current mouse cursor's position relative to the
        receiving widget, while **oldPos** is its previous such position.
        **modifiers** hold the state of all keyboard modifiers at the time of
        the event.
        """
        ...

    def clone(self) -> "QHoverEvent":
        ...

    def oldPosF(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qhoverevent.html#oldPosF

        **QPointF QHoverEvent::oldPosF() const**

        Returns the previous position of the mouse cursor, relative to the
        widget that received the event. If there is no previous position,
        oldPosF() will return the same position as posF().

        On **QEvent::HoverEnter**  events, this position will always be
        **QPointF** (-1, -1).

        **See also** **posF** ().
        """
        ...

    def oldPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qhoverevent.html#oldPos

        **QPoint QHoverEvent::oldPos() const**

        Returns the previous position of the mouse cursor, relative to the
        widget that received the event. If there is no previous position,
        oldPos() will return the same position as pos().

        On **QEvent::HoverEnter**  events, this position will always be
        **QPoint** (-1, -1).

        **See also** **pos** ().
        """
        ...

    def isUpdateEvent(self) -> bool:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QSharedMemory(QObject):
    """
    https://doc.qt.io/qt-6/qsharedmemory.html

    **Detailed Description**

    QSharedMemory provides access to a shared memory segment by multiple threads
    and processes. It also provides a way for a single thread or process to lock
    the memory for exclusive access.

    When using this class, be aware of the following platform differences:

    * Windows: QSharedMemory does not "own" the shared memory segment. When all
    threads or processes that have an instance of QSharedMemory attached to a
    particular shared memory segment have either destroyed their instance of
    QSharedMemory or exited, the Windows kernel releases the shared memory
    segment automatically.
      * Unix: QSharedMemory "owns" the shared memory
    segment. When the last thread or process that has an instance of
    QSharedMemory attached to a particular shared memory segment detaches from
    the segment by destroying its instance of QSharedMemory, the Unix kernel
    release the shared memory segment. But if that last thread or process
    crashes without running the QSharedMemory destructor, the shared memory
    segment survives the crash.
      * HP-UX: Only one attach to a shared memory
    segment is allowed per process. This means that QSharedMemory should not be
    used across multiple threads in the same process in HP-UX.
      * Apple
    platforms: Sandboxed applications (including apps shipped through the Apple
    App Store) require the use of POSIX shared memory (instead of System V
    shared memory), which adds a number of limitations, including:
        * The key
    must be in the form `<application group identifier>/<custom identifier>`, as
    documented **here**  and **here** .
        * The key length is limited to 30
    characters.
        * On process exit, the named shared memory entries are not
    cleaned up, so restarting the application and re-creating the shared memory
    under the same name will fail. To work around this, fall back to attaching
    to the existing shared memory entry:
    **QSharedMemory**  shm("DEVTEAMID.app-group/shared");
            if
    (!shm.create(42) && shm.error() == **QSharedMemory** ::AlreadyExists)
    shm.attach();

    Remember to lock the shared memory with **lock** () before reading from or
    writing to the shared memory, and remember to release the lock with
    **unlock** () after you are done.

    QSharedMemory automatically destroys the shared memory segment when the last
    instance of QSharedMemory is detached from the segment, and no references to
    the segment remain.

    **Warning:** QSharedMemory changes the key in a Qt-specific way, unless
    otherwise specified. Interoperation with non-Qt applications is achieved by
    first creating a default shared memory with QSharedMemory() and then setting
    a native key with **setNativeKey** (). When using native keys, shared memory
    is not protected against multiple accesses on it (for example, unable to
    **lock** ()) and a user-defined mechanism should be used to achieve such
    protection.
    """

    class SharedMemoryError(enum.Enum):
        NoError: QSharedMemory = ...
        PermissionDenied: QSharedMemory = ...
        InvalidSize: QSharedMemory = ...
        KeyError: QSharedMemory = ...
        AlreadyExists: QSharedMemory = ...
        NotFound: QSharedMemory = ...
        LockError: QSharedMemory = ...
        OutOfResources: QSharedMemory = ...
        UnknownError: QSharedMemory = ...

    class AccessMode(enum.Enum):
        ReadOnly: QSharedMemory = ...
        ReadWrite: QSharedMemory = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#QSharedMemory

        **QSharedMemory::QSharedMemory(const QString & key , QObject * parent =
        nullptr)**

        Constructs a shared memory object with the given **parent** and with its
        key set to **key**. Because its key is set, its **create** () and
        **attach** () functions can be called.

        **See also** **setKey** (), **create** (), and **attach** ().
        """
        ...

    @typing.overload
    def __init__(self, key: str, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#QSharedMemory-1

        **QSharedMemory::QSharedMemory(QObject * parent = nullptr)**

        This function overloads QSharedMemory().

        Constructs a shared memory object with the given **parent**. The shared
        memory object's key is not set by the constructor, so the shared memory
        object does not have an underlying shared memory segment attached. The
        key must be set with **setKey** () or **setNativeKey** () before
        **create** () or **attach** () can be used.

        **See also** **setKey** ().
        """
        ...

    def nativeKey(self) -> str:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#nativeKey

        **QString QSharedMemory::nativeKey() const**

        Returns the native, platform specific, key for this shared memory
        object. The native key is the identifier used by the operating system to
        identify the shared memory segment.

        You can use the native key to access shared memory segments that have
        not been created by Qt, or to grant shared memory access to non-Qt
        applications.

        **See also** **setKey** () and **setNativeKey** ().
        """
        ...

    def setNativeKey(self, key: str) -> None:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#setNativeKey

        **void QSharedMemory::setNativeKey(const QString & key )**

        Sets the native, platform specific, **key** for this shared memory
        object. If **key** is the same as the current native key, the function
        returns without doing anything. If all you want is to assign a key to a
        segment, you should call **setKey** () instead.

        You can call **nativeKey** () to retrieve the native key. If a native
        key has been assigned, calling **key** () will return a null string.

        If the shared memory object is attached to an underlying shared memory
        segment, it will **detach**  from it before setting the new key. This
        function does not do an **attach** ().

        The application will not be portable if you set a native key.

        **See also** **nativeKey** (), **key** (), and **isAttached** ().
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#errorString

        **QString QSharedMemory::errorString() const**

        Returns a text description of the last error that occurred. If **error**
        () returns an **error value** , call this function to get a text string
        that describes the error.

        **See also** **error** ().
        """
        ...

    def error(self) -> "QSharedMemory.SharedMemoryError":
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#error

        **QSharedMemory::SharedMemoryError QSharedMemory::error() const**

        Returns a value indicating whether an error occurred, and, if so, which
        error it was.

        **See also** **errorString** ().
        """
        ...

    def unlock(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#unlock

        **bool QSharedMemory::unlock()**

        Releases the lock on the shared memory segment and returns `true`, if
        the lock is currently held by this process. If the segment is not
        locked, or if the lock is held by another process, nothing happens and
        false is returned.

        **See also** **lock** ().
        """
        ...

    def lock(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#lock

        **bool QSharedMemory::lock()**

        This is a semaphore that locks the shared memory segment for access by
        this process and returns `true`. If another process has locked the
        segment, this function blocks until the lock is released. Then it
        acquires the lock and returns `true`. If this function returns `false`,
        it means that you have ignored a false return from **create** () or
        **attach** (), that you have set the key with **setNativeKey** () or
        that **QSystemSemaphore::acquire** () failed due to an unknown system
        error.

        **See also** **unlock** (), **data** (), and
        **QSystemSemaphore::acquire** ().
        """
        ...

    def constData(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#constData

        **const void *QSharedMemory::constData() const**

        Returns a const pointer to the contents of the shared memory segment, if
        one is attached. Otherwise it returns null. Remember to lock the shared
        memory with **lock** () before reading from or writing to the shared
        memory, and remember to release the lock with **unlock** () after you
        are done.

        **See also** **attach** () and **create** ().
        """
        ...

    def data(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#data

        **void *QSharedMemory::data()**

        Returns a pointer to the contents of the shared memory segment, if one
        is attached. Otherwise it returns null. Remember to lock the shared
        memory with **lock** () before reading from or writing to the shared
        memory, and remember to release the lock with **unlock** () after you
        are done.

        **See also** **attach** ().
        """
        ...

    def detach(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#detach

        **bool QSharedMemory::detach()**

        Detaches the process from the shared memory segment. If this was the
        last process attached to the shared memory segment, then the shared
        memory segment is released by the system, i.e., the contents are
        destroyed. The function returns `true` if it detaches the shared memory
        segment. If it returns `false`, it usually means the segment either
        isn't attached, or it is locked by another process.

        **See also** **attach** () and **isAttached** ().
        """
        ...

    def isAttached(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#isAttached

        **bool QSharedMemory::isAttached() const**

        Returns `true` if this process is attached to the shared memory segment.

        **See also** **attach** () and **detach** ().
        """
        ...

    def attach(self, mode: "QSharedMemory.AccessMode" = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#attach

        **bool QSharedMemory::attach(QSharedMemory::AccessMode mode =
        ReadWrite)**

        Attempts to attach the process to the shared memory segment identified
        by the key that was passed to the constructor or to a call to **setKey**
        () or **setNativeKey** (). The access **mode** is **ReadWrite**  by
        default. It can also be **ReadOnly** . Returns `true` if the attach
        operation is successful. If false is returned, call **error** () to
        determine which error occurred. After attaching the shared memory
        segment, a pointer to the shared memory can be obtained by calling
        **data** ().

        **See also** **isAttached** (), **detach** (), and **create** ().
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#size

        **qsizetype QSharedMemory::size() const**

        Returns the size of the attached shared memory segment. If no shared
        memory segment is attached, 0 is returned.

        **Note:** The size of the segment may be larger than the requested size
        that was passed to **create** ().

        **See also** **create** () and **attach** ().
        """
        ...

    def create(self, size: int, mode: "QSharedMemory.AccessMode" = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#create

        **bool QSharedMemory::create(qsizetype size , QSharedMemory::AccessMode
        mode = ReadWrite)**

        Creates a shared memory segment of **size** bytes with the key passed to
        the constructor, set with **setKey** () or set with **setNativeKey** (),
        then attaches to the new shared memory segment with the given access
        **mode** and returns `true`. If a shared memory segment identified by
        the key already exists, the attach operation is not performed and
        `false` is returned. When the return value is `false`, call **error** ()
        to determine which error occurred.

        **See also** **error** ().
        """
        ...

    def key(self) -> str:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#key

        **QString QSharedMemory::key() const**

        Returns the key assigned with **setKey** () to this shared memory, or a
        null key if no key has been assigned, or if the segment is using a
        **nativeKey** (). The key is the identifier used by Qt applications to
        identify the shared memory segment.

        You can find the native, platform specific, key used by the operating
        system by calling **nativeKey** ().

        **See also** **setKey** () and **setNativeKey** ().
        """
        ...

    def setKey(self, key: str) -> None:
        """
        https://doc.qt.io/qt-6/qsharedmemory.html#setKey

        **void QSharedMemory::setKey(const QString & key )**

        Sets the platform independent **key** for this shared memory object. If
        **key** is the same as the current key, the function returns without
        doing anything.

        You can call **key** () to retrieve the platform independent key.
        Internally, **QSharedMemory**  converts this key into a platform
        specific key. If you instead call **nativeKey** (), you will get the
        platform specific, converted key.

        If the shared memory object is attached to an underlying shared memory
        segment, it will **detach**  from it before setting the new key. This
        function does not do an **attach** ().

        **See also** **key** (), **nativeKey** (), and **isAttached** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6.QtSensors import *
import enum


class QTapReading(QSensorReading):
    class TapDirection(enum.Enum):
        Undefined: QTapReading = ...
        X: QTapReading = ...
        Y: QTapReading = ...
        Z: QTapReading = ...
        X_Pos: QTapReading = ...
        Y_Pos: QTapReading = ...
        Z_Pos: QTapReading = ...
        X_Neg: QTapReading = ...
        Y_Neg: QTapReading = ...
        Z_Neg: QTapReading = ...
        X_Both: QTapReading = ...
        Y_Both: QTapReading = ...
        Z_Both: QTapReading = ...

    def setDoubleTap(self, doubleTap: bool) -> None:
        ...

    def isDoubleTap(self) -> bool:
        ...

    def setTapDirection(self, tapDirection: "QTapReading.TapDirection") -> None:
        ...

    def tapDirection(self) -> "QTapReading.TapDirection":
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtRemoteObjects import *


class QRemoteObjectHost(QRemoteObjectHostBase):
    """
    https://doc.qt.io/qt-6/qremoteobjecthost.html

    **Detailed Description**

    The QRemoteObjectHost class provides an entry point to a **QtRemoteObjects**
    network. A network can be as simple as two nodes, or an arbitrarily complex
    set of processes and devices.

    QRemoteObjectHosts have the same capabilities as QRemoteObjectNodes, but
    they can also be connected to and can share source objects on the network.

    Nodes may connect to each other directly using **connectToNode** , or they
    can use the **QRemoteObjectRegistry**  to simplify connections.

    The **QRemoteObjectRegistry**  is a special replica available to every node
    that connects to the registry Url. It knows how to connect to every
    QRemoteObjectSource object on the network.

    **See also** **QRemoteObjectNode**  and **QRemoteObjectRegistryHost** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjecthost.html#QRemoteObjectHost

        **QRemoteObjectHost::QRemoteObjectHost(QObject * parent = nullptr)**

        Constructs a new QRemoteObjectHost Node (i.e., a Node that supports
        exposing **Source**  objects on the QtRO network) with the given
        **parent**. This constructor is meant specific to support QML in the
        future as it will not be available to connect to until **setHostUrl**
        is called.

        **See also** **setHostUrl** () and **setRegistryUrl** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        address: QtCore.QUrl,
        registryAddress: QtCore.QUrl = ...,
        allowedSchemas: QRemoteObjectHostBase.AllowedSchemas = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjecthost.html#QRemoteObjectHost-1

        **QRemoteObjectHost::QRemoteObjectHost(const QUrl & address , const QUrl
        & registryAddress = QUrl(), QRemoteObjectHostBase::AllowedSchemas
        allowedSchemas = BuiltInSchemasOnly, QObject * parent = nullptr)**

        Constructs a new QRemoteObjectHost Node (i.e., a Node that supports
        exposing **Source**  objects on the QtRO network) with address
        **address**. If set, **registryAddress** will be used to connect to the
        **QRemoteObjectRegistry**  at the provided address. The
        **allowedSchemas** parameter is only needed (and should be set to
        **AllowExternalRegistration** ) if the schema of the url should be used
        as an **External Schema**  by the registry.

        **See also** **setHostUrl** () and **setRegistryUrl** ().
        """
        ...

    @typing.overload
    def __init__(self, address: QtCore.QUrl, parent: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjecthost.html#QRemoteObjectHost-2

        **QRemoteObjectHost::QRemoteObjectHost(const QUrl & address , QObject *
        parent )**

        Constructs a new QRemoteObjectHost Node (i.e., a Node that supports
        exposing **Source**  objects on the QtRO network) with a url of
        **address** and the given **parent**. This overload is provided as a
        convenience for specifying a **QObject**  parent without providing a
        registry address.

        **See also** **setHostUrl** () and **setRegistryUrl** ().
        """
        ...

    def setHostUrl(
        self,
        hostAddress: QtCore.QUrl,
        allowedSchemas: QRemoteObjectHostBase.AllowedSchemas = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjecthost.html#setHostUrl

        **[override virtual] bool QRemoteObjectHost::setHostUrl(const QUrl &
        hostAddress , QRemoteObjectHostBase::AllowedSchemas allowedSchemas =
        BuiltInSchemasOnly)**

        Sets the **hostAddress** for a host **QRemoteObjectNode** .

        Returns `true` if the Host address is set, otherwise `false`.

        The **allowedSchemas** parameter is only needed (and should be set to
        **AllowExternalRegistration** ) if the schema of the url should be used
        as an **External Schema**  by the registry.

        **Note:** Setter function for property **hostUrl** .

        **See also** **hostUrl** ().
        """
        ...

    def hostUrl(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qremoteobjecthost.html#hostUrl

        **[override virtual] QUrl QRemoteObjectHost::hostUrl() const**

        Returns the host address for the **QRemoteObjectNode**  as a **QUrl** .
        If the Node is not a Host node, returns an empty **QUrl** .

        **Note:** Getter function for property hostUrl.

        **See also** **setHostUrl** ().
        """
        ...

    @property
    def hostUrlChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QSqlRelation(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsqlrelation.html

    **Detailed Description**

    QSqlRelation is a helper class for **QSqlRelationalTableModel** . See
    **QSqlRelationalTableModel::setRelation** () and
    **QSqlRelationalTableModel::relation** () for details.

    **See also** **QSqlRelationalTableModel** , **QSqlRelationalDelegate** , and
    **Relational Table Model Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelation.html#QSqlRelation

        **QSqlRelation::QSqlRelation()**

        Constructs an invalid QSqlRelation object.

        For such an object, the **tableName** (), **indexColumn** (), and
        **displayColumn** () functions return an empty string.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, aTableName: str, indexCol: str, displayCol: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelation.html#QSqlRelation-1

        **QSqlRelation::QSqlRelation(const QString & tableName , const QString &
        indexColumn , const QString & displayColumn )**

        Constructs a QSqlRelation object, where **tableName** is the SQL table
        name to which a foreign key refers, **indexColumn** is the foreign key,
        and **displayColumn** is the field that should be presented to the user.

        **See also** **tableName** (), **indexColumn** (), and **displayColumn**
        ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QSqlRelation") -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelation.html#QSqlRelation

        **QSqlRelation::QSqlRelation()**

        Constructs an invalid QSqlRelation object.

        For such an object, the **tableName** (), **indexColumn** (), and
        **displayColumn** () functions return an empty string.

        **See also** **isValid** ().
        """
        ...

    def swap(self, other: "QSqlRelation") -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelation.html#swap

        **void QSqlRelation::swap(QSqlRelation & other )**

        Swaps `this` with **other**.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrelation.html#isValid

        **bool QSqlRelation::isValid() const**

        Returns `true` if the **QSqlRelation**  object is valid; otherwise
        returns `false`.
        """
        ...

    def displayColumn(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlrelation.html#displayColumn

        **QString QSqlRelation::displayColumn() const**

        Returns the column from table **tableName** () that should be presented
        to the user instead of a foreign key.
        """
        ...

    def indexColumn(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlrelation.html#indexColumn

        **QString QSqlRelation::indexColumn() const**

        Returns the index column from table **tableName** () to which a foreign
        key refers.
        """
        ...

    def tableName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlrelation.html#tableName

        **QString QSqlRelation::tableName() const**

        Returns the name of the table to which a foreign key refers.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QResizeEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qresizeevent.html

    **Detailed Description**

    Resize events are sent to widgets that have been resized.

    The event handler **QWidget::resizeEvent** () receives resize events.

    **See also** **QWidget::resize** () and **QWidget::setGeometry** ().
    """

    def __init__(self, size: QtCore.QSize, oldSize: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qresizeevent.html#QResizeEvent-2

        **QResizeEvent::QResizeEvent(const QSize & size , const QSize & oldSize
        )**

        Constructs a resize event with the new and old widget sizes, **size**
        and **oldSize** respectively.
        """
        ...

    def clone(self) -> "QResizeEvent":
        ...

    def oldSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qresizeevent.html#oldSize

        **const QSize &QResizeEvent::oldSize() const**

        Returns the old size of the widget.
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qresizeevent.html#size

        **const QSize &QResizeEvent::size() const**

        Returns the new size of the widget. This is the same as
        **QWidget::size** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QSslCertificateExtension(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsslcertificateextension.html

    **Detailed Description**

    QSslCertificateExtension provides access to an extension stored in an X509
    certificate. The information available depends on the type of extension
    being accessed.

    All X509 certificate extensions have the following properties:

    PropertyDescription
    nameThe human readable name of the extension, eg.
    'basicConstraints'.
    criticalityThis is a boolean value indicating if the
    extension is critical to correctly interpreting the certificate.
    oidThe
    ASN.1 object identifier that specifies which extension this is.
    supportedIf this is true the structure of the extension's value will not
    change between Qt versions.
    valueA **QVariant**  with a structure
    dependent on the type of extension.

    Whilst this class provides access to any type of extension, only some are
    guaranteed to be returned in a format that will remain unchanged between
    releases. The **isSupported** () method returns `true` for extensions where
    this is the case.

    The extensions currently supported, and the structure of the value returned
    are as follows:

    NameOIDDetails
    basicConstraints2.5.29.19Returned as a QVariantMap. The key
    'ca' contains a boolean value, the optional key 'pathLenConstraint' contains
    an integer.
    authorityInfoAccess1.3.6.1.5.5.7.1.1Returned as a QVariantMap.
    There is a key for each access method, with the value being a URI.
    subjectKeyIdentifier2.5.29.14Returned as a **QVariant**  containing a
    **QString** . The string is the key identifier.
    authorityKeyIdentifier2.5.29.35Returned as a QVariantMap. The optional key
    'keyid' contains the key identifier as a hex string stored in a
    **QByteArray** . The optional key 'serial' contains the authority key serial
    number as a qlonglong. Currently there is no support for the general names
    field of this extension.

    In addition to the supported extensions above, many other common extensions
    will be returned in a reasonably structured way. Extensions that the SSL
    backend has no support for at all will be returned as a **QByteArray** .

    Further information about the types of extensions certificates can contain
    can be found in RFC 5280.

    **See also** **QSslCertificate::extensions** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsslcertificateextension.html#QSslCertificateExte
        nsion

        **QSslCertificateExtension::QSslCertificateExtension()**

        Constructs a QSslCertificateExtension.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSslCertificateExtension") -> None:
        """
        https://doc.qt.io/qt-6/qsslcertificateextension.html#QSslCertificateExte
        nsion-1

        **QSslCertificateExtension::QSslCertificateExtension(const
        QSslCertificateExtension & other )**

        Constructs a copy of **other**.
        """
        ...

    def isSupported(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslcertificateextension.html#isSupported

        **bool QSslCertificateExtension::isSupported() const**

        Returns the true if this extension is supported. In this case, supported
        simply means that the structure of the **QVariant**  returned by the
        **value** () accessor will remain unchanged between versions.
        Unsupported extensions can be freely used, however there is no guarantee
        that the returned data will have the same structure between versions.
        """
        ...

    def isCritical(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslcertificateextension.html#isCritical

        **bool QSslCertificateExtension::isCritical() const**

        Returns the criticality of the extension.
        """
        ...

    def value(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsslcertificateextension.html#value

        **QVariant QSslCertificateExtension::value() const**

        Returns the value of the extension. The structure of the value returned
        depends on the extension type.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcertificateextension.html#name

        **QString QSslCertificateExtension::name() const**

        Returns the name of the extension. If no name is known for the extension
        then the OID will be returned.
        """
        ...

    def oid(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcertificateextension.html#oid

        **QString QSslCertificateExtension::oid() const**

        Returns the ASN.1 OID of this extension.
        """
        ...

    def swap(self, other: "QSslCertificateExtension") -> None:
        """
        https://doc.qt.io/qt-6/qsslcertificateextension.html#swap

        **void QSslCertificateExtension::swap(QSslCertificateExtension & other
        )**

        Swaps this certificate extension instance with **other**. This function
        is very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QHelpFilterData(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhelpfilterdata.html

    **Detailed Description**

    By using **setComponents** () you may constrain the search results to
    documents that belong only to components specified on the given list. By
    using **setVersions** () you may constrain the search results to documents
    that belong only to versions specified on the given list.

    **See also** **QHelpFilterEngine** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#QHelpFilterData

        **QHelpFilterData::QHelpFilterData()**

        Constructs the empty filter.
        """
        ...

    @typing.overload
    def __init__(self, other: "QHelpFilterData") -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#QHelpFilterData-1

        **QHelpFilterData::QHelpFilterData(const QHelpFilterData & other )**

        Constructs a copy of **other**.
        """
        ...

    def versions(self) -> typing.List[QtCore.QVersionNumber]:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#versions

        **QList<QVersionNumber> QHelpFilterData::versions() const**

        Returns the version list that is used for filtering the search results.

        **See also** **setVersions** ().
        """
        ...

    def components(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#components

        **QStringList QHelpFilterData::components() const**

        Returns the component list that is used for filtering the search
        results.

        **See also** **setComponents** ().
        """
        ...

    def setVersions(self, versions: typing.Iterable[QtCore.QVersionNumber]) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#setVersions

        **void QHelpFilterData::setVersions(const QList<QVersionNumber> &
        versions )**

        Specifies the version list that is used for filtering the search
        results. Only results from versions in the list **versions** shall be
        returned.

        **See also** **versions** ().
        """
        ...

    def setComponents(self, components: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#setComponents

        **void QHelpFilterData::setComponents(const QStringList & components )**

        Specifies the component list that is used for filtering the search
        results. Only results from components in the list **components** shall
        be returned.

        **See also** **components** ().
        """
        ...

    def swap(self, other: "QHelpFilterData") -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#swap

        **void QHelpFilterData::swap(QHelpFilterData & other )**

        Swaps the filter **other** with this filter. This operation is very fast
        and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QColorConstants(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcolorconstants.html

    **Detailed Description**

    These constants are usable everywhere a **QColor**  object is expected:

    painter.setBrush(QColorConstants::Svg::lightblue);

    Their usage is much cheaper than e.g. passing a string to **QColor** 's
    constructor, as they don't require any parsing of the string, and always
    result in a valid **QColor**  object:

    object.setColor(QColor("lightblue")); // expensive

    **Qt Colors**

    The following colors are defined in the `QColorConstants` namespace:

    NameHexColor
    Color0#000000

    Color1#ffffff

    Black#000000
    White#ffffff

    DarkGray#808080

    Gray#a0a0a4

    LightGray#c0c0c0
    Red#ff0000

    Green#00ff00

    Blue#0000ff

    Cyan#00ffff
    Magenta#ff00ff

    Yellow#ffff00

    DarkRed#800000

    DarkGreen#008000
    DarkBlue#000080

    DarkCyan#008080

    DarkMagenta#800080
    DarkYellow#808000

    Transparent#00000000(transparent)

    **SVG Colors**

    The following table lists the available **SVG colors** . They are available
    in the `QColorConstants::Svg` inner namespace.

    NameHexColor
    aliceblue#f0f8ff

    antiquewhite#faebd7

    aqua#00ffff
    aquamarine#7fffd4

    azure#f0ffff

    beige#f5f5dc

    bisque#ffe4c4
    black#000000

    blanchedalmond#ffebcd

    blue#0000ff
    blueviolet#8a2be2

    brown#a52a2a

    burlywood#deb887
    cadetblue#5f9ea0

    chartreuse#7fff00

    chocolate#d2691e
    coral#ff7f50

    cornflowerblue#6495ed

    cornsilk#fff8dc
    crimson#dc143c

    cyan#00ffff

    darkblue#00008b

    darkcyan#008b8b
    darkgoldenrod#b8860b

    darkgray#a9a9a9

    darkgreen#006400
    darkgrey#a9a9a9

    darkkhaki#bdb76b

    darkmagenta#8b008b
    darkolivegreen#556b2f

    darkorange#ff8c00

    darkorchid#9932cc
    darkred#8b0000

    darksalmon#e9967a

    darkseagreen#8fbc8f
    darkslateblue#483d8b

    darkslategray#2f4f4f

    darkslategrey#2f4f4f
    darkturquoise#00ced1

    darkviolet#9400d3

    deeppink#ff1493
    deepskyblue#00bfff

    dimgray#696969

    dimgrey#696969
    dodgerblue#1e90ff

    firebrick#b22222

    floralwhite#fffaf0
    forestgreen#228b22

    fuchsia#ff00ff

    gainsboro#dcdcdc
    ghostwhite#f8f8ff

    gold#ffd700

    goldenrod#daa520

    gray#808080
    grey#808080

    green#008000

    greenyellow#adff2f

    honeydew#f0fff0
    hotpink#ff69b4

    indianred#cd5c5c

    indigo#4b0082

    ivory#fffff0
    khaki#f0e68c

    lavender#e6e6fa

    lavenderblush#fff0f5
    lawngreen#7cfc00

    lemonchiffon#fffacd

    lightblue#add8e6
    lightcoral#f08080

    lightcyan#e0ffff

    lightgoldenrodyellow#fafad2
    lightgray#d3d3d3

    lightgreen#90ee90

    lightgrey#d3d3d3
    lightpink#ffb6c1

    lightsalmon#ffa07a

    lightseagreen#20b2aa
    lightskyblue#87cefa

    lightslategray#778899

    lightslategrey#778899
    lightsteelblue#b0c4de

    lightyellow#ffffe0

    lime#00ff00
    limegreen#32cd32

    linen#faf0e6

    magenta#ff00ff

    maroon#800000
    mediumaquamarine#66cdaa

    mediumblue#0000cd

    mediumorchid#ba55d3
    mediumpurple#9370db

    mediumseagreen#3cb371

    mediumslateblue#7b68ee
    mediumspringgreen#00fa9a

    mediumturquoise#48d1cc
    mediumvioletred#c71585

    midnightblue#191970

    mintcream#f5fffa
    mistyrose#ffe4e1

    moccasin#ffe4b5

    navajowhite#ffdead
    navy#000080

    oldlace#fdf5e6

    olive#808000

    olivedrab#6b8e23
    orange#ffa500

    orangered#ff4500

    orchid#da70d6
    palegoldenrod#eee8aa

    palegreen#98fb98

    paleturquoise#afeeee
    palevioletred#db7093

    papayawhip#ffefd5

    peachpuff#ffdab9
    peru#cd853f

    pink#ffc0cb

    plum#dda0dd

    powderblue#b0e0e6
    purple#800080

    red#ff0000

    rosybrown#bc8f8f

    royalblue#4169e1
    saddlebrown#8b4513

    salmon#fa8072

    sandybrown#f4a460
    seagreen#2e8b57

    seashell#fff5ee

    sienna#a0522d

    silver#c0c0c0
    skyblue#87ceeb

    slateblue#6a5acd

    slategray#708090
    slategrey#708090

    snow#fffafa

    springgreen#00ff7f
    steelblue#4682b4

    tan#d2b48c

    teal#008080

    thistle#d8bfd8
    tomato#ff6347

    turquoise#40e0d0

    violet#ee82ee

    wheat#f5deb3
    white#ffffff

    whitesmoke#f5f5f5

    yellow#ffff00
    yellowgreen#9acd32

    **See also** **QColor**  and **Qt::GlobalColor** .
    """

    class Svg(PyQt6.sip.simplewrapper):
        aliceblue: typing = ...
        antiquewhite: typing = ...
        aqua: typing = ...
        aquamarine: typing = ...
        azure: typing = ...
        beige: typing = ...
        bisque: typing = ...
        black: typing = ...
        blanchedalmond: typing = ...
        blue: typing = ...
        blueviolet: typing = ...
        brown: typing = ...
        burlywood: typing = ...
        cadetblue: typing = ...
        chartreuse: typing = ...
        chocolate: typing = ...
        coral: typing = ...
        cornflowerblue: typing = ...
        cornsilk: typing = ...
        crimson: typing = ...
        cyan: typing = ...
        darkblue: typing = ...
        darkcyan: typing = ...
        darkgoldenrod: typing = ...
        darkgray: typing = ...
        darkgreen: typing = ...
        darkgrey: typing = ...
        darkkhaki: typing = ...
        darkmagenta: typing = ...
        darkolivegreen: typing = ...
        darkorange: typing = ...
        darkorchid: typing = ...
        darkred: typing = ...
        darksalmon: typing = ...
        darkseagreen: typing = ...
        darkslateblue: typing = ...
        darkslategray: typing = ...
        darkslategrey: typing = ...
        darkturquoise: typing = ...
        darkviolet: typing = ...
        deeppink: typing = ...
        deepskyblue: typing = ...
        dimgray: typing = ...
        dimgrey: typing = ...
        dodgerblue: typing = ...
        firebrick: typing = ...
        floralwhite: typing = ...
        forestgreen: typing = ...
        fuchsia: typing = ...
        gainsboro: typing = ...
        ghostwhite: typing = ...
        gold: typing = ...
        goldenrod: typing = ...
        gray: typing = ...
        green: typing = ...
        greenyellow: typing = ...
        grey: typing = ...
        honeydew: typing = ...
        hotpink: typing = ...
        indianred: typing = ...
        indigo: typing = ...
        ivory: typing = ...
        khaki: typing = ...
        lavender: typing = ...
        lavenderblush: typing = ...
        lawngreen: typing = ...
        lemonchiffon: typing = ...
        lightblue: typing = ...
        lightcoral: typing = ...
        lightcyan: typing = ...
        lightgoldenrodyellow: typing = ...
        lightgray: typing = ...
        lightgreen: typing = ...
        lightgrey: typing = ...
        lightpink: typing = ...
        lightsalmon: typing = ...
        lightseagreen: typing = ...
        lightskyblue: typing = ...
        lightslategray: typing = ...
        lightslategrey: typing = ...
        lightsteelblue: typing = ...
        lightyellow: typing = ...
        lime: typing = ...
        limegreen: typing = ...
        linen: typing = ...
        magenta: typing = ...
        maroon: typing = ...
        mediumaquamarine: typing = ...
        mediumblue: typing = ...
        mediumorchid: typing = ...
        mediumpurple: typing = ...
        mediumseagreen: typing = ...
        mediumslateblue: typing = ...
        mediumspringgreen: typing = ...
        mediumturquoise: typing = ...
        mediumvioletred: typing = ...
        midnightblue: typing = ...
        mintcream: typing = ...
        mistyrose: typing = ...
        moccasin: typing = ...
        navajowhite: typing = ...
        navy: typing = ...
        oldlace: typing = ...
        olive: typing = ...
        olivedrab: typing = ...
        orange: typing = ...
        orangered: typing = ...
        orchid: typing = ...
        palegoldenrod: typing = ...
        palegreen: typing = ...
        paleturquoise: typing = ...
        palevioletred: typing = ...
        papayawhip: typing = ...
        peachpuff: typing = ...
        peru: typing = ...
        pink: typing = ...
        plum: typing = ...
        powderblue: typing = ...
        purple: typing = ...
        red: typing = ...
        rosybrown: typing = ...
        royalblue: typing = ...
        saddlebrown: typing = ...
        salmon: typing = ...
        sandybrown: typing = ...
        seagreen: typing = ...
        seashell: typing = ...
        sienna: typing = ...
        silver: typing = ...
        skyblue: typing = ...
        slateblue: typing = ...
        slategray: typing = ...
        slategrey: typing = ...
        snow: typing = ...
        springgreen: typing = ...
        steelblue: typing = ...
        tan: typing = ...
        teal: typing = ...
        thistle: typing = ...
        tomato: typing = ...
        turquoise: typing = ...
        violet: typing = ...
        wheat: typing = ...
        white: typing = ...
        whitesmoke: typing = ...
        yellow: typing = ...
        yellowgreen: typing = ...

    Black: typing = ...
    Blue: typing = ...
    Color0: typing = ...
    Color1: typing = ...
    Cyan: typing = ...
    DarkBlue: typing = ...
    DarkCyan: typing = ...
    DarkGray: typing = ...
    DarkGreen: typing = ...
    DarkMagenta: typing = ...
    DarkRed: typing = ...
    DarkYellow: typing = ...
    Gray: typing = ...
    Green: typing = ...
    LightGray: typing = ...
    Magenta: typing = ...
    Red: typing = ...
    Transparent: typing = ...
    White: typing = ...
    Yellow: typing = ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtQuick import *


class QSGVertexColorMaterial(QSGMaterial):
    """
    https://doc.qt.io/qt-6/qsgvertexcolormaterial.html

    **Detailed Description**

    **Warning:** This utility class is only functional when running with the
    default backend of the Qt Quick scenegraph.

    The vertex color material will give each vertex in a geometry a color.
    Pixels between vertices will be linearly interpolated. The colors can
    contain transparency.

    The geometry to be rendered with vertex color must have the following
    layout. Attribute position 0 must contain vertices. Attribute position 1
    must contain colors, a tuple of 4 values with RGBA layout. Both floats in
    the range of 0 to 1 and unsigned bytes in the range 0 to 255 are valid for
    the color values.

    **Note:** The rendering pipeline expects pixels with premultiplied alpha.

    **QSGGeometry::defaultAttributes_ColoredPoint2D** () can be used to
    construct an attribute set that is compatible with this material.

    The vertex color material respects both current opacity and current matrix
    when updating it's rendering state.
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgvertexcolormaterial.html#QSGVertexColorMateria
        l

        **QSGVertexColorMaterial::QSGVertexColorMaterial()**

        Creates a new vertex color material.
        """
        ...

    def createShader(
        self, renderMode: QSGRendererInterface.RenderMode
    ) -> QSGMaterialShader:
        ...

    def type(self) -> QSGMaterialType:
        ...

    def compare(self, other: QSGMaterial) -> int:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QNdefFilter import QNdefFilter as QNdefFilter
from ._QNdefMessage import QNdefMessage as QNdefMessage
from ._QNdefRecord import QNdefRecord as QNdefRecord
from ._QNdefNfcIconRecord import QNdefNfcIconRecord as QNdefNfcIconRecord
from ._QNdefNfcSmartPosterRecord import (
    QNdefNfcSmartPosterRecord as QNdefNfcSmartPosterRecord,
)
from ._QNdefNfcTextRecord import QNdefNfcTextRecord as QNdefNfcTextRecord
from ._QNdefNfcUriRecord import QNdefNfcUriRecord as QNdefNfcUriRecord
from ._QNearFieldManager import QNearFieldManager as QNearFieldManager
from ._QNearFieldTarget import QNearFieldTarget as QNearFieldTarget



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtMultimedia import *
import enum


class QMediaMetaData(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmediametadata.html

    **Detailed Description**

    **Note:** Not all identifiers are supported on all platforms.

    Common attributes
    ValueDescriptionType
    TitleThe title of the
    media.**QString**
    AuthorThe authors of the media.**QStringList**
    CommentA user comment about the media.**QString**
    DescriptionA description
    of the media.**QString**
    GenreThe genre of the media.**QStringList**
    DateThe date of the media.**QDate** .
    LanguageThe language of
    media.**QLocale::Language**
    PublisherThe publisher of the
    media.**QString**
    CopyrightThe media's copyright notice.**QString**
    UrlA
    Url pointing to the origin of the media.**QUrl**
    Media attributes
    MediaTypeThe type of the media (audio, video, etc).**QString**
    FileFormatThe file format of the media.**QMediaFormat::FileFormat**
    DurationThe duration in millseconds of the media.qint64
    Audio attributes
    AudioBitRateThe bit rate of the media's audio stream in bits per second.int
    AudioCodecThe codec of the media's audio stream.QMediaForma::AudioCodec
    Video attributes
    VideoFrameRateThe frame rate of the media's video
    stream.qreal
    VideoBitRateThe bit rate of the media's video stream in bits
    per second.int
    VideoCodecThe codec of the media's video
    stream.**QMediaFormat::VideoCodec**
    Music attributes
    AlbumTitleThe title
    of the album the media belongs to.**QString**
    AlbumArtistThe principal
    artist of the album the media belongs to.**QString**
    ContributingArtistThe
    artists contributing to the media.**QStringList**
    TrackNumberThe track
    number of the media.int
    ComposerThe composer of the media.**QStringList**
    LeadPerformerThe lead performer in the media.**QStringList**
    ThumbnailImageAn embedded thumbnail image.**QImage**
    CoverArtImageAn
    embedded cover art image.**QImage**
    Image and video attributes
    ResolutionThe dimensions of an image or video.**QSize**
    """

    class Key(enum.Enum):
        Title: QMediaMetaData = ...
        Author: QMediaMetaData = ...
        Comment: QMediaMetaData = ...
        Description: QMediaMetaData = ...
        Genre: QMediaMetaData = ...
        Date: QMediaMetaData = ...
        Language: QMediaMetaData = ...
        Publisher: QMediaMetaData = ...
        Copyright: QMediaMetaData = ...
        Url: QMediaMetaData = ...
        Duration: QMediaMetaData = ...
        MediaType: QMediaMetaData = ...
        FileFormat: QMediaMetaData = ...
        AudioBitRate: QMediaMetaData = ...
        AudioCodec: QMediaMetaData = ...
        VideoBitRate: QMediaMetaData = ...
        VideoCodec: QMediaMetaData = ...
        VideoFrameRate: QMediaMetaData = ...
        AlbumTitle: QMediaMetaData = ...
        AlbumArtist: QMediaMetaData = ...
        ContributingArtist: QMediaMetaData = ...
        TrackNumber: QMediaMetaData = ...
        Composer: QMediaMetaData = ...
        LeadPerformer: QMediaMetaData = ...
        ThumbnailImage: QMediaMetaData = ...
        CoverArtImage: QMediaMetaData = ...
        Orientation: QMediaMetaData = ...
        Resolution: QMediaMetaData = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QMediaMetaData") -> None:
        ...

    @staticmethod
    def metaDataKeyToString(k: "QMediaMetaData.Key") -> str:
        """
        https://doc.qt.io/qt-6/qmediametadata.html#metaDataKeyToString

        **[static invokable] QString
        QMediaMetaData::metaDataKeyToString(QMediaMetaData::Key key )**

        returns a string representation of **key** that can be used when
        presenting meta data to users.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def stringValue(self, k: "QMediaMetaData.Key") -> str:
        """
        https://doc.qt.io/qt-6/qmediametadata.html#stringValue

        **[invokable] QString QMediaMetaData::stringValue(QMediaMetaData::Key
        key ) const**

        Returns the meta data for key **key** as a **QString** .

        This is mainly meant to simplify presenting the meta data to a user.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def keys(self) -> typing.List["QMediaMetaData.Key"]:
        """
        https://doc.qt.io/qt-6/qmediametadata.html#keys

        **[invokable] QList<QMediaMetaData::Key> QMediaMetaData::keys() const**

        Returns a **QList**  of QMediaMetaData::Keys.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def insert(self, k: "QMediaMetaData.Key", value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qmediametadata.html#insert

        **[invokable] void QMediaMetaData::insert(QMediaMetaData::Key k , const
        QVariant & value )**

        Inserts a **value** into a Key: **k**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def value(self, k: "QMediaMetaData.Key") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmediametadata.html#value

        **[invokable] QVariant QMediaMetaData::value(QMediaMetaData::Key key )
        const**

        Returns the meta data value for Key **key** , or a null **QVariant**  if
        no meta data for the key is available.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QDir(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdir.html

    **Detailed Description**

    A QDir is used to manipulate path names, access information regarding paths
    and files, and manipulate the underlying file system. It can also be used to
    access Qt's **resource system** .

    Qt uses "/" as a universal directory separator in the same way that "/" is
    used as a path separator in URLs. If you always use "/" as a directory
    separator, Qt will translate your paths to conform to the underlying
    operating system.

    A QDir can point to a file using either a relative or an absolute path.
    Absolute paths begin with the directory separator (optionally preceded by a
    drive specification under Windows). Relative file names begin with a
    directory name or a file name and specify a path relative to the current
    directory.

    Examples of absolute paths:

    **QDir** ("/home/user/Documents")
        **QDir** ("C:/Documents and Settings")

    On Windows, the second example above will be translated to `C:\\Documents and
    Settings` when used to access files.

    Examples of relative paths:

    **QDir** ("images/landscape.png")

    You can use the **isRelative** () or **isAbsolute** () functions to check if
    a QDir is using a relative or an absolute file path. Call **makeAbsolute**
    () to convert a relative QDir to an absolute one.

    **Note:** Paths starting with a colon ( **:** ) are always considered
    absolute, as they denote a **QResource** .

    **Navigation and Directory Operations**

    A directory's path can be obtained with the **path** () function, and a new
    path set with the **setPath** () function. The absolute path to a directory
    is found by calling **absolutePath** ().

    The name of a directory is found using the **dirName** () function. This
    typically returns the last element in the absolute path that specifies the
    location of the directory. However, it can also return "." if the QDir
    represents the current directory.

    **QDir** ("Documents/Letters/Applications").dirName() // "Applications"
    **QDir** ().dirName()                                 // "."

    The path for a directory can also be changed with the **cd** () and **cdUp**
    () functions, both of which operate like familiar shell commands. When
    **cd** () is called with the name of an existing directory, the QDir object
    changes directory so that it represents that directory instead. The **cdUp**
    () function changes the directory of the QDir object so that it refers to
    its parent directory; i.e. cd("..") is equivalent to **cdUp** ().

    Directories can be created with **mkdir** (), renamed with **rename** (),
    and removed with **rmdir** ().

    You can test for the presence of a directory with a given name by using
    **exists** (), and the properties of a directory can be tested with
    **isReadable** (), **isAbsolute** (), **isRelative** (), and **isRoot** ().

    The **refresh** () function re-reads the directory's data from disk.

    **Files and Directory Contents**

    Directories contain a number of entries, representing files, directories,
    and symbolic links. The number of entries in a directory is returned by
    **count** (). A string list of the names of all the entries in a directory
    can be obtained with **entryList** (). If you need information about each
    entry, use **entryInfoList** () to obtain a list of **QFileInfo**  objects.

    Paths to files and directories within a directory can be constructed using
    **filePath** () and **absoluteFilePath** (). The **filePath** () function
    returns a path to the specified file or directory relative to the path of
    the QDir object; **absoluteFilePath** () returns an absolute path to the
    specified file or directory. Neither of these functions checks for the
    existence of files or directory; they only construct paths.

    **QDir**  directory("Documents/Letters");
        **QString**  path =
    directory.filePath("contents.txt");
        **QString**  absolutePath =
    directory.absoluteFilePath("contents.txt");

    Files can be removed by using the **remove** () function. Directories cannot
    be removed in the same way as files; use **rmdir** () to remove them
    instead.

    It is possible to reduce the number of entries returned by **entryList** ()
    and **entryInfoList** () by applying filters to a QDir object. You can apply
    a name filter to specify a pattern with wildcards that file names need to
    match, an attribute filter that selects properties of entries and can
    distinguish between files and directories, and a sort order.

    Name filters are lists of strings that are passed to **setNameFilters** ().
    Attribute filters consist of a bitwise OR combination of Filters, and these
    are specified when calling **setFilter** (). The sort order is specified
    using **setSorting** () with a bitwise OR combination of **SortFlags** .

    You can test to see if a filename matches a filter using the **match** ()
    function.

    Filter and sort order flags may also be specified when calling **entryList**
    () and **entryInfoList** () in order to override previously defined
    behavior.

    **The Current Directory and Other Special Paths**

    Access to some common directories is provided with a number of static
    functions that return QDir objects. There are also corresponding functions
    for these that return strings:

    QDir**QString** Return Value
    **current** ()**currentPath** ()The
    application's working directory
    **home** ()**homePath** ()The user's home
    directory
    **root** ()**rootPath** ()The root directory
    **temp**
    ()**tempPath** ()The system's temporary directory

    The **setCurrent** () static function can also be used to set the
    application's working directory.

    If you want to find the directory containing the application's executable,
    see **QCoreApplication::applicationDirPath** ().

    The **drives** () static function provides a list of root directories for
    each device that contains a filing system. On Unix systems this returns a
    list containing a single root directory "/"; on Windows the list will
    usually contain `C:/`, and possibly other drive letters such as `D:/`,
    depending on the configuration of the user's system.

    **Path Manipulation and Strings**

    Paths containing "." elements that reference the current directory at that
    point in the path, ".." elements that reference the parent directory, and
    symbolic links can be reduced to a canonical form using the
    **canonicalPath** () function.

    Paths can also be simplified by using **cleanPath** () to remove redundant
    "/" and ".." elements.

    It is sometimes necessary to be able to show a path in the native
    representation for the user's platform. The static **toNativeSeparators** ()
    function returns a copy of the specified path in which each directory
    separator is replaced by the appropriate separator for the underlying
    operating system.

    **Examples**

    Check if a directory exists:

    **QDir**  dir("example");
        if (!dir.exists())
            **qWarning**
    ("Cannot find the example directory");

    (We could also use the static convenience function **QFile::exists** ().)

    Traversing directories and reading a file:

    **QDir**  dir = **QDir** ::root();                 // "/"
        if
    (!dir.cd("tmp")) {                    // "/tmp"
            **qWarning**
    ("Cannot find the \\"/tmp\\" directory");
        } else {
            **QFile**
    file(dir.filePath("ex1.txt")); // "/tmp/ex1.txt"
            if
    (!file.open(**QIODevice** ::ReadWrite))
                **qWarning** ("Cannot
    create the file %s", file.name());
        }

    A program that lists all the files in the current directory (excluding
    symbolic links), sorted by size, smallest first:

    #include <QDir>
        #include <iostream>

        int main(int argc, char
    *argv[])
        {
            **QCoreApplication**  app(argc, argv);
    **QDir**  dir;
            dir.setFilter(**QDir** ::Files | **QDir** ::Hidden |
    **QDir** ::NoSymLinks);
            dir.setSorting(**QDir** ::Size | **QDir**
    ::Reversed);

            **QFileInfoList**  list = dir.entryInfoList();
    std::cout << "     Bytes Filename" << std::endl;
            for (int i = 0; i <
    list.size(); ++i) {
                **QFileInfo**  fileInfo = list.at(i);
    std::cout << **qPrintable** (**QString** ("%1 %2").arg(fileInfo.size(), 10)
    .arg(fileInfo.fileName()));
                std::cout << std::endl;
            }
    return 0;
        }

    **See also** **QFileInfo** , **QFile** , **QFileDialog** ,
    **QCoreApplication::applicationDirPath** (), and **Find Files Example** .
    """

    class SortFlag(enum.Flag):
        Name: QDir = ...
        Time: QDir = ...
        Size: QDir = ...
        Unsorted: QDir = ...
        SortByMask: QDir = ...
        DirsFirst: QDir = ...
        Reversed: QDir = ...
        IgnoreCase: QDir = ...
        DirsLast: QDir = ...
        LocaleAware: QDir = ...
        Type: QDir = ...
        NoSort: QDir = ...

    class Filter(enum.Flag):
        Dirs: QDir = ...
        Files: QDir = ...
        Drives: QDir = ...
        NoSymLinks: QDir = ...
        AllEntries: QDir = ...
        TypeMask: QDir = ...
        Readable: QDir = ...
        Writable: QDir = ...
        Executable: QDir = ...
        PermissionMask: QDir = ...
        Modified: QDir = ...
        Hidden: QDir = ...
        System: QDir = ...
        AccessMask: QDir = ...
        AllDirs: QDir = ...
        CaseSensitive: QDir = ...
        NoDotAndDotDot: QDir = ...
        NoFilter: QDir = ...
        NoDot: QDir = ...
        NoDotDot: QDir = ...

    @typing.overload
    def __init__(
        self,
        path: str,
        nameFilter: str,
        sort: "QDir.SortFlag" = ...,
        filters: "QDir.Filter" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#QDir

        **QDir::QDir(const QDir & dir )**

        Constructs a QDir object that is a copy of the QDir object for directory
        **dir**.

        **See also** **operator=** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDir") -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#QDir-1

        **QDir::QDir(const QString & path = QString())**

        Constructs a QDir pointing to the given directory **path**. If path is
        empty the program's working directory, ("."), is used.

        **See also** **currentPath** ().
        """
        ...

    @typing.overload
    def __init__(self, path: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#QDir-2

        **QDir::QDir(const QString & path , const QString & nameFilter ,
        QDir::SortFlags sort = SortFlags(Name | IgnoreCase), QDir::Filters
        filters = AllEntries)**

        Constructs a QDir with path **path** , that filters its entries by name
        using **nameFilter** and by attributes using **filters**. It also sorts
        the names using **sort**.

        The default **nameFilter** is an empty string, which excludes nothing;
        the default **filters** is **AllEntries** , which also excludes nothing.
        The default **sort** is **Name**  | **IgnoreCase** , i.e. sort by name
        case-insensitively.

        If **path** is an empty string, QDir uses "." (the current directory).
        If **nameFilter** is an empty string, QDir uses the name filter "*" (all
        files).

        **Note:** **path** need not exist.

        **See also** **exists** (), **setPath** (), **setNameFilters** (),
        **setFilter** (), and **setSorting** ().
        """
        ...

    def isEmpty(self, filters: "QDir.Filter" = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#isEmpty

        **[since 5.9] bool QDir::isEmpty(QDir::Filters filters =
        Filters(AllEntries | NoDotAndDotDot)) const**

        Returns whether the directory is empty.

        Equivalent to `count() == 0` with filters `QDir::AllEntries |
        QDir::NoDotAndDotDot`, but faster as it just checks whether the
        directory contains at least one entry.

        **Note:** Unless you set the **filters** flags to include
        `QDir::NoDotAndDotDot` (as the default value does), no directory is
        empty.

        This function was introduced in Qt 5.9.

        **See also** **count** (), **entryList** (), and **setFilter** ().
        """
        ...

    @staticmethod
    def listSeparator() -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#listSeparator

        **[static, since 5.6] QChar QDir::listSeparator()**

        Returns the native path list separator: ':' under Unix and ';' under
        Windows.

        This function was introduced in Qt 5.6.

        **See also** **separator** ().
        """
        ...

    def swap(self, other: "QDir") -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#swap

        **[since 5.0] void QDir::swap(QDir & other )**

        Swaps this **QDir**  instance with **other**. This function is very fast
        and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def removeRecursively(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#removeRecursively

        **[since 5.0] bool QDir::removeRecursively()**

        Removes the directory, including all its contents.

        Returns `true` if successful, otherwise false.

        If a file or directory cannot be removed, removeRecursively() keeps
        going and attempts to delete as many files and sub-directories as
        possible, then returns `false`.

        If the directory was already removed, the method returns `true`
        (expected result already reached).

        **Note:** This function is meant for removing a small application-
        internal directory (such as a temporary directory), but not user-visible
        directories. For user-visible operations, it is rather recommended to
        report errors more precisely to the user, to offer solutions in case of
        errors, to show progress during the deletion since it could take several
        minutes, etc.

        This function was introduced in Qt 5.0.
        """
        ...

    @staticmethod
    def searchPaths(prefix: str) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qdir.html#searchPaths

        **[static] QStringList QDir::searchPaths(const QString & prefix )**

        Returns the search paths for **prefix**.

        **See also** **setSearchPaths** () and **addSearchPath** ().
        """
        ...

    @staticmethod
    def addSearchPath(prefix: str, path: str) -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#addSearchPath

        **[static] void QDir::addSearchPath(const QString & prefix , const
        QString & path )**

        Adds **path** to the search path for **prefix**.

        **See also** **setSearchPaths** ().
        """
        ...

    @staticmethod
    def setSearchPaths(prefix: str, searchPaths: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#setSearchPaths

        **[static] void QDir::setSearchPaths(const QString & prefix , const
        QStringList & searchPaths )**

        Sets or replaces Qt's search paths for file names with the prefix
        **prefix** to **searchPaths**.

        To specify a prefix for a file name, prepend the prefix followed by a
        single colon (e.g., "images:undo.png", "xmldocs:books.xml"). **prefix**
        can only contain letters or numbers (e.g., it cannot contain a colon,
        nor a slash).

        Qt uses this search path to locate files with a known prefix. The search
        path entries are tested in order, starting with the first entry.

        **QDir** ::setSearchPaths("icons", **QStringList** (**QDir**
        ::homePath() + "/images"));
            **QDir** ::setSearchPaths("docs",
        **QStringList** (":/embeddedDocuments"));
            ...
            **QPixmap**
        pixmap("icons:undo.png"); // will look for undo.png in QDir::homePath()
        + "/images"
            **QFile**  file("docs:design.odf"); // will look in the
        :/embeddedDocuments resource path

        File name prefix must be at least 2 characters long to avoid conflicts
        with Windows drive letters.

        Search paths may contain paths to **The Qt Resource System** .

        **See also** **searchPaths** ().
        """
        ...

    @staticmethod
    def fromNativeSeparators(pathName: str) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#fromNativeSeparators

        **[static] QString QDir::fromNativeSeparators(const QString & pathName
        )**

        Returns **pathName** using '/' as file separator. On Windows, for
        instance, fromNativeSeparators("`c:\\\\winnt\\\\system32`") returns
        "c:/winnt/system32".

        The returned string may be the same as the argument on some operating
        systems, for example on Unix.

        **See also** **toNativeSeparators** () and **separator** ().
        """
        ...

    @staticmethod
    def toNativeSeparators(pathName: str) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#toNativeSeparators

        **[static] QString QDir::toNativeSeparators(const QString & pathName )**

        Returns **pathName** with the '/' separators converted to separators
        that are appropriate for the underlying operating system.

        On Windows, toNativeSeparators("c:/winnt/system32") returns
        "c:\\winnt\\system32".

        The returned string may be the same as the argument on some operating
        systems, for example on Unix.

        **See also** **fromNativeSeparators** () and **separator** ().
        """
        ...

    @staticmethod
    def cleanPath(path: str) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#cleanPath

        **[static] QString QDir::cleanPath(const QString & path )**

        Returns **path** with directory separators normalized (that is,
        platform-native separators converted to "/") and redundant ones removed,
        and "."s and ".."s resolved (as far as possible).

        Symbolic links are kept. This function does not return the canonical
        path, but rather the simplest version of the input. For example,
        "./local" becomes "local", "local/../bin" becomes "bin" and
        "/local/usr/../bin" becomes "/local/bin".

        **See also** **absolutePath** () and **canonicalPath** ().
        """
        ...

    @typing.overload
    @staticmethod
    def match(filters: typing.Iterable[str], fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#match

        **[static] bool QDir::match(const QString & filter , const QString &
        fileName )**

        Returns `true` if the **fileName** matches the wildcard (glob) pattern
        **filter** ; otherwise returns `false`. The **filter** may contain
        multiple patterns separated by spaces or semicolons. The matching is
        case insensitive.

        **See also** **QRegularExpression::fromWildcard** (), **entryList** (),
        and **entryInfoList** ().
        """
        ...

    @typing.overload
    @staticmethod
    def match(filter: str, fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#match-1

        **[static] bool QDir::match(const QStringList & filters , const QString
        & fileName )**

        This is an overloaded function.

        Returns `true` if the **fileName** matches any of the wildcard (glob)
        patterns in the list of **filters** ; otherwise returns `false`. The
        matching is case insensitive.

        **See also** **QRegularExpression::fromWildcard** (), **entryList** (),
        and **entryInfoList** ().
        """
        ...

    @staticmethod
    def tempPath() -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#tempPath

        **[static] QString QDir::tempPath()**

        Returns the absolute canonical path of the system's temporary directory.

        On Unix/Linux systems this is the path in the `TMPDIR` environment
        variable or `/tmp` if `TMPDIR` is not defined. On Windows this is
        usually the path in the `TEMP` or `TMP` environment variable. The path
        returned by this method doesn't end with a directory separator unless it
        is the root directory (of a drive).

        **See also** **temp** (), **currentPath** (), **homePath** (), and
        **rootPath** ().
        """
        ...

    @staticmethod
    def temp() -> "QDir":
        """
        https://doc.qt.io/qt-6/qdir.html#temp

        **[static] QDir QDir::temp()**

        Returns the system's temporary directory.

        The directory is constructed using the absolute canonical path of the
        temporary directory, ensuring that its **path** () will be the same as
        its **absolutePath** ().

        See **tempPath** () for details.

        **See also** **drives** (), **current** (), **home** (), and **root**
        ().
        """
        ...

    @staticmethod
    def rootPath() -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#rootPath

        **[static] QString QDir::rootPath()**

        Returns the absolute path of the root directory.

        For Unix operating systems this returns "/". For Windows file systems
        this normally returns "c:/".

        **See also** **root** (), **drives** (), **currentPath** (),
        **homePath** (), and **tempPath** ().
        """
        ...

    @staticmethod
    def root() -> "QDir":
        """
        https://doc.qt.io/qt-6/qdir.html#root

        **[static] QDir QDir::root()**

        Returns the root directory.

        The directory is constructed using the absolute path of the root
        directory, ensuring that its **path** () will be the same as its
        **absolutePath** ().

        See **rootPath** () for details.

        **See also** **drives** (), **current** (), **home** (), and **temp**
        ().
        """
        ...

    @staticmethod
    def homePath() -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#homePath

        **[static] QString QDir::homePath()**

        Returns the absolute path of the user's home directory.

        Under Windows this function will return the directory of the current
        user's profile. Typically, this is:

        C:/Documents and Settings/Username

        Use the **toNativeSeparators** () function to convert the separators to
        the ones that are appropriate for the underlying operating system.

        If the directory of the current user's profile does not exist or cannot
        be retrieved, the following alternatives will be checked (in the given
        order) until an existing and available path is found:

        1. The path specified by the `USERPROFILE` environment variable.
          2.
        The path formed by concatenating the `HOMEDRIVE` and `HOMEPATH`
        environment variables.
          3. The path specified by the `HOME` environment
        variable.
          4. The path returned by the **rootPath** () function (which
        uses the `SystemDrive` environment variable)
          5. The `C:/` directory.

        Under non-Windows operating systems the `HOME` environment variable is
        used if it exists, otherwise the path returned by the **rootPath** ().

        **See also** **home** (), **currentPath** (), **rootPath** (), and
        **tempPath** ().
        """
        ...

    @staticmethod
    def home() -> "QDir":
        """
        https://doc.qt.io/qt-6/qdir.html#home

        **[static] QDir QDir::home()**

        Returns the user's home directory.

        The directory is constructed using the absolute path of the home
        directory, ensuring that its **path** () will be the same as its
        **absolutePath** ().

        See **homePath** () for details.

        **See also** **drives** (), **current** (), **root** (), and **temp**
        ().
        """
        ...

    @staticmethod
    def currentPath() -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#currentPath

        **[static] QString QDir::currentPath()**

        Returns the absolute path of the application's current directory. The
        current directory is the last directory set with **QDir::setCurrent** ()
        or, if that was never called, the directory at which this application
        was started at by the parent process.

        **See also** **current** (), **setCurrent** (), **homePath** (),
        **rootPath** (), **tempPath** (), and
        **QCoreApplication::applicationDirPath** ().
        """
        ...

    @staticmethod
    def current() -> "QDir":
        """
        https://doc.qt.io/qt-6/qdir.html#current

        **[static] QDir QDir::current()**

        Returns the application's current directory.

        The directory is constructed using the absolute path of the current
        directory, ensuring that its **path** () will be the same as its
        **absolutePath** ().

        **See also** **currentPath** (), **setCurrent** (), **home** (),
        **root** (), and **temp** ().
        """
        ...

    @staticmethod
    def setCurrent(path: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#setCurrent

        **[static] bool QDir::setCurrent(const QString & path )**

        Sets the application's current working directory to **path**. Returns
        `true` if the directory was successfully changed; otherwise returns
        `false`.

        **QString**  absolute = "/local/bin";
            **QString**  relative =
        "local/bin";
            **QFileInfo**  absFile(absolute);
            **QFileInfo**
        relFile(relative);

            **QDir** ::setCurrent(**QDir**
        ::rootPath());
            // absFile and relFile now point to the same file
        **QDir** ::setCurrent("/tmp");
            // absFile now points to
        "/local/bin",
            // while relFile points to "/tmp/local/bin"

        **See also** **current** (), **currentPath** (), **home** (), **root**
        (), and **temp** ().
        """
        ...

    @staticmethod
    def separator() -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#separator

        **[static] QChar QDir::separator()**

        Returns the native directory separator: "/" under Unix and "\\" under
        Windows.

        You do not need to use this function to build file paths. If you always
        use "/", Qt will translate your paths to conform to the underlying
        operating system. If you want to display paths to the user using their
        operating system's separator use **toNativeSeparators** ().

        **See also** **listSeparator** ().
        """
        ...

    @staticmethod
    def drives() -> typing.List["QFileInfo"]:
        """
        https://doc.qt.io/qt-6/qdir.html#drives

        **[static] QFileInfoList QDir::drives()**

        Returns a list of the root directories on this system.

        On Windows this returns a list of **QFileInfo**  objects containing
        "C:/", "D:/", etc. On other operating systems, it returns a list
        containing just one root directory (i.e. "/").

        **See also** **root** () and **rootPath** ().
        """
        ...

    def refresh(self) -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#refresh

        **void QDir::refresh() const**

        Refreshes the directory information.
        """
        ...

    def rename(self, oldName: str, newName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#rename

        **bool QDir::rename(const QString & oldName , const QString & newName
        )**

        Renames a file or directory from **oldName** to **newName** , and
        returns true if successful; otherwise returns `false`.

        On most file systems, rename() fails only if **oldName** does not exist,
        or if a file with the new name already exists. However, there are also
        other reasons why rename() can fail. For example, on at least one file
        system rename() fails if **newName** points to an open file.

        If **oldName** is a file (not a directory) that can't be renamed right
        away, Qt will try to copy **oldName** to **newName** and remove
        **oldName**.

        **See also** **QFile::rename** ().
        """
        ...

    def remove(self, fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#remove

        **bool QDir::remove(const QString & fileName )**

        Removes the file, **fileName**.

        Returns `true` if the file is removed successfully; otherwise returns
        `false`.
        """
        ...

    def makeAbsolute(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#makeAbsolute

        **bool QDir::makeAbsolute()**

        Converts the directory path to an absolute path. If it is already
        absolute nothing happens. Returns `true` if the conversion succeeded;
        otherwise returns `false`.

        **See also** **isAbsolute** (), **isAbsolutePath** (), **isRelative**
        (), and **cleanPath** ().
        """
        ...

    def isAbsolute(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#isAbsolute

        **bool QDir::isAbsolute() const**

        Returns `true` if the directory's path is absolute; otherwise returns
        `false`. See **isAbsolutePath** ().

        **Note:** Paths starting with a colon ( **:** ) are always considered
        absolute, as they denote a **QResource** .

        **See also** **isRelative** (), **makeAbsolute** (), and **cleanPath**
        ().
        """
        ...

    def isRelative(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#isRelative

        **bool QDir::isRelative() const**

        Returns `true` if the directory path is relative; otherwise returns
        false. (Under Unix a path is relative if it does not start with a "/").

        **Note:** Paths starting with a colon ( **:** ) are always considered
        absolute, as they denote a **QResource** .

        **See also** **makeAbsolute** (), **isAbsolute** (), **isAbsolutePath**
        (), and **cleanPath** ().
        """
        ...

    @staticmethod
    def isAbsolutePath(path: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#isAbsolutePath

        **[static] bool QDir::isAbsolutePath(const QString & path )**

        Returns `true` if **path** is absolute; returns `false` if it is
        relative.

        **Note:** Paths starting with a colon ( **:** ) are always considered
        absolute, as they denote a **QResource** .

        **See also** **isAbsolute** (), **isRelativePath** (), **makeAbsolute**
        (), **cleanPath** (), and **QResource** .
        """
        ...

    @staticmethod
    def isRelativePath(path: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#isRelativePath

        **[static] bool QDir::isRelativePath(const QString & path )**

        Returns `true` if **path** is relative; returns `false` if it is
        absolute.

        **Note:** Paths starting with a colon ( **:** ) are always considered
        absolute, as they denote a **QResource** .

        **See also** **isRelative** (), **isAbsolutePath** (), and
        **makeAbsolute** ().
        """
        ...

    def isRoot(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#isRoot

        **bool QDir::isRoot() const**

        Returns `true` if the directory is the root directory; otherwise returns
        `false`.

        **Note:** If the directory is a symbolic link to the root directory this
        function returns `false`. If you want to test for this use
        **canonicalPath** (), e.g.

        **QDir**  dir("/tmp/root_link");
            dir = dir.canonicalPath();
            if
        (dir.isRoot())
                **qWarning** ("It is a root link");

        **See also** **root** () and **rootPath** ().
        """
        ...

    @typing.overload
    def exists(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#exists

        **bool QDir::exists(const QString & name ) const**

        Returns `true` if the file called **name** exists; otherwise returns
        false.

        Unless **name** contains an absolute file path, the file name is assumed
        to be relative to the directory itself, so this function is typically
        used to check for the presence of files within a directory.

        **See also** **QFileInfo::exists** () and **QFile::exists** ().
        """
        ...

    @typing.overload
    def exists(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#exists-1

        **bool QDir::exists() const**

        This is an overloaded function.

        Returns `true` if the directory exists; otherwise returns `false`. (If a
        file with the same name is found this function will return false).

        The overload of this function that accepts an argument is used to test
        for the presence of files and directories within a directory.

        **See also** **QFileInfo::exists** () and **QFile::exists** ().
        """
        ...

    def isReadable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#isReadable

        **bool QDir::isReadable() const**

        Returns `true` if the directory is readable **and** we can open files by
        name; otherwise returns `false`.

        **Warning:** A false value from this function is not a guarantee that
        files in the directory are not accessible.

        **See also** **QFileInfo::isReadable** ().
        """
        ...

    def rmpath(self, dirPath: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#rmpath

        **bool QDir::rmpath(const QString & dirPath ) const**

        Removes the directory path **dirPath**.

        The function will remove all parent directories in **dirPath** ,
        provided that they are empty. This is the opposite of mkpath(dirPath).

        Returns `true` if successful; otherwise returns `false`.

        **See also** **mkpath** ().
        """
        ...

    def mkpath(self, dirPath: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#mkpath

        **bool QDir::mkpath(const QString & dirPath ) const**

        Creates the directory path **dirPath**.

        The function will create all parent directories necessary to create the
        directory.

        Returns `true` if successful; otherwise returns `false`.

        If the path already exists when this function is called, it will return
        true.

        **See also** **rmpath** ().
        """
        ...

    def rmdir(self, dirName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#rmdir

        **bool QDir::rmdir(const QString & dirName ) const**

        Removes the directory specified by **dirName**.

        The directory must be empty for rmdir() to succeed.

        Returns `true` if successful; otherwise returns `false`.

        **See also** **mkdir** ().
        """
        ...

    def mkdir(self, dirName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#mkdir

        **bool QDir::mkdir(const QString & dirName ) const**

        Creates a sub-directory called **dirName**.

        Returns `true` on success; otherwise returns `false`.

        If the directory already exists when this function is called, it will
        return false.

        **See also** **rmdir** ().
        """
        ...

    @typing.overload
    def entryInfoList(
        self, filters: "QDir.Filter" = ..., sort: "QDir.SortFlag" = ...
    ) -> typing.List["QFileInfo"]:
        """
        https://doc.qt.io/qt-6/qdir.html#entryInfoList

        **QFileInfoList QDir::entryInfoList(const QStringList & nameFilters ,
        QDir::Filters filters = NoFilter, QDir::SortFlags sort = NoSort) const**

        Returns a list of **QFileInfo**  objects for all the files and
        directories in the directory, ordered according to the name and
        attribute filters previously set with **setNameFilters** () and
        **setFilter** (), and sorted according to the flags set with
        **setSorting** ().

        The name filter, file attribute filter, and sorting specification can be
        overridden using the **nameFilters** , **filters** , and **sort**
        arguments.

        Returns an empty list if the directory is unreadable, does not exist, or
        if nothing matches the specification.

        **See also** **entryList** (), **setNameFilters** (), **setSorting** (),
        **setFilter** (), **isReadable** (), and **exists** ().
        """
        ...

    @typing.overload
    def entryInfoList(
        self,
        nameFilters: typing.Iterable[str],
        filters: "QDir.Filter" = ...,
        sort: "QDir.SortFlag" = ...,
    ) -> typing.List["QFileInfo"]:
        """
        https://doc.qt.io/qt-6/qdir.html#entryInfoList-1

        **QFileInfoList QDir::entryInfoList(QDir::Filters filters = NoFilter,
        QDir::SortFlags sort = NoSort) const**

        This is an overloaded function.

        Returns a list of **QFileInfo**  objects for all the files and
        directories in the directory, ordered according to the name and
        attribute filters previously set with **setNameFilters** () and
        **setFilter** (), and sorted according to the flags set with
        **setSorting** ().

        The attribute filter and sorting specifications can be overridden using
        the **filters** and **sort** arguments.

        Returns an empty list if the directory is unreadable, does not exist, or
        if nothing matches the specification.

        **See also** **entryList** (), **setNameFilters** (), **setSorting** (),
        **setFilter** (), **isReadable** (), and **exists** ().
        """
        ...

    @typing.overload
    def entryList(
        self, filters: "QDir.Filter" = ..., sort: "QDir.SortFlag" = ...
    ) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qdir.html#entryList

        **QStringList QDir::entryList(const QStringList & nameFilters ,
        QDir::Filters filters = NoFilter, QDir::SortFlags sort = NoSort) const**

        Returns a list of the names of all the files and directories in the
        directory, ordered according to the name and attribute filters
        previously set with **setNameFilters** () and **setFilter** (), and
        sorted according to the flags set with **setSorting** ().

        The name filter, file attribute filter, and sorting specification can be
        overridden using the **nameFilters** , **filters** , and **sort**
        arguments.

        Returns an empty list if the directory is unreadable, does not exist, or
        if nothing matches the specification.

        **See also** **entryInfoList** (), **setNameFilters** (), **setSorting**
        (), and **setFilter** ().
        """
        ...

    @typing.overload
    def entryList(
        self,
        nameFilters: typing.Iterable[str],
        filters: "QDir.Filter" = ...,
        sort: "QDir.SortFlag" = ...,
    ) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qdir.html#entryList-1

        **QStringList QDir::entryList(QDir::Filters filters = NoFilter,
        QDir::SortFlags sort = NoSort) const**

        This is an overloaded function.

        Returns a list of the names of all the files and directories in the
        directory, ordered according to the name and attribute filters
        previously set with **setNameFilters** () and **setFilter** (), and
        sorted according to the flags set with **setSorting** ().

        The attribute filter and sorting specifications can be overridden using
        the **filters** and **sort** arguments.

        Returns an empty list if the directory is unreadable, does not exist, or
        if nothing matches the specification.

        **Note:** To list symlinks that point to non existing files, **System**
        must be passed to the filter.

        **See also** **entryInfoList** (), **setNameFilters** (), **setSorting**
        (), and **setFilter** ().
        """
        ...

    @staticmethod
    def nameFiltersFromString(nameFilter: str) -> typing.List[str]:
        ...

    def __contains__(self, a0: str) -> int:
        ...

    @typing.overload
    def __getitem__(self, a0: int) -> str:
        ...

    @typing.overload
    def __getitem__(self, a0: slice) -> typing.List[str]:
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qdir.html#count

        **uint QDir::count() const**

        Returns the total number of directories and files in the directory.

        Equivalent to **entryList** ().count().

        **See also** **operator[]** () and **entryList** ().
        """
        ...

    def setSorting(self, sort: "QDir.SortFlag") -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#setSorting

        **void QDir::setSorting(QDir::SortFlags sort )**

        Sets the sort order used by **entryList** () and **entryInfoList** ().

        The **sort** is specified by OR-ing values from the enum
        **QDir::SortFlag** .

        **See also** **sorting** () and **SortFlag** .
        """
        ...

    def sorting(self) -> "QDir.SortFlag":
        """
        https://doc.qt.io/qt-6/qdir.html#sorting

        **QDir::SortFlags QDir::sorting() const**

        Returns the value set by **setSorting** ()

        **See also** **setSorting** () and **SortFlag** .
        """
        ...

    def setFilter(self, filter: "QDir.Filter") -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#setFilter

        **void QDir::setFilter(QDir::Filters filters )**

        Sets the filter used by **entryList** () and **entryInfoList** () to
        **filters**. The filter is used to specify the kind of files that should
        be returned by **entryList** () and **entryInfoList** (). See
        **QDir::Filter** .

        **See also** **filter** () and **setNameFilters** ().
        """
        ...

    def filter(self) -> "QDir.Filter":
        """
        https://doc.qt.io/qt-6/qdir.html#filter

        **QDir::Filters QDir::filter() const**

        Returns the value set by **setFilter** ()

        **See also** **setFilter** ().
        """
        ...

    def setNameFilters(self, nameFilters: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#setNameFilters

        **void QDir::setNameFilters(const QStringList & nameFilters )**

        Sets the name filters used by **entryList** () and **entryInfoList** ()
        to the list of filters specified by **nameFilters**.

        Each name filter is a wildcard (globbing) filter that understands `*`
        and `?` wildcards. See **QRegularExpression::fromWildcard** ().

        For example, the following code sets three name filters on a **QDir**
        to ensure that only files with extensions typically used for C++ source
        files are listed:

        **QStringList**  filters;
                filters << "*.cpp" << "*.cxx" <<
        "*.cc";
                dir.setNameFilters(filters);

        **See also** **nameFilters** () and **setFilter** ().
        """
        ...

    def nameFilters(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qdir.html#nameFilters

        **QStringList QDir::nameFilters() const**

        Returns the string list set by **setNameFilters** ()

        **See also** **setNameFilters** ().
        """
        ...

    def cdUp(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#cdUp

        **bool QDir::cdUp()**

        Changes directory by moving one directory up from the **QDir** 's
        current directory.

        Returns `true` if the new directory exists; otherwise returns `false`.
        Note that the logical cdUp() operation is not performed if the new
        directory does not exist.

        **See also** **cd** (), **isReadable** (), **exists** (), and **path**
        ().
        """
        ...

    def cd(self, dirName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdir.html#cd

        **bool QDir::cd(const QString & dirName )**

        Changes the **QDir** 's directory to **dirName**.

        Returns `true` if the new directory exists; otherwise returns `false`.
        Note that the logical cd() operation is not performed if the new
        directory does not exist.

        Calling cd("..") is equivalent to calling **cdUp** ().

        **See also** **cdUp** (), **isReadable** (), **exists** (), and **path**
        ().
        """
        ...

    def relativeFilePath(self, fileName: str) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#relativeFilePath

        **QString QDir::relativeFilePath(const QString & fileName ) const**

        Returns the path to **fileName** relative to the directory.

        **QDir**  dir("/home/bob");
            **QString**  s;

            s =
        dir.relativeFilePath("images/file.jpg");     // s is "images/file.jpg"
        s = dir.relativeFilePath("/home/mary/file.txt"); // s is
        "../mary/file.txt"

        **See also** **absoluteFilePath** (), **filePath** (), and
        **canonicalPath** ().
        """
        ...

    def absoluteFilePath(self, fileName: str) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#absoluteFilePath

        **QString QDir::absoluteFilePath(const QString & fileName ) const**

        Returns the absolute path name of a file in the directory. Does **not**
        check if the file actually exists in the directory; but see **exists**
        (). Redundant multiple separators or "." and ".." directories in
        **fileName** are not removed (see **cleanPath** ()).

        **See also** **relativeFilePath** (), **filePath** (), and
        **canonicalPath** ().
        """
        ...

    def filePath(self, fileName: str) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#filePath

        **QString QDir::filePath(const QString & fileName ) const**

        Returns the path name of a file in the directory. Does **not** check if
        the file actually exists in the directory; but see **exists** (). If the
        **QDir**  is relative the returned path name will also be relative.
        Redundant multiple separators or "." and ".." directories in
        **fileName** are not removed (see **cleanPath** ()).

        **See also** **dirName** (), **absoluteFilePath** (), **isRelative** (),
        and **canonicalPath** ().
        """
        ...

    def dirName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#dirName

        **QString QDir::dirName() const**

        Returns the name of the directory; this is **not** the same as the path,
        e.g. a directory with the name "mail", might have the path
        "/var/spool/mail". If the directory has no name (e.g. it is the root
        directory) an empty string is returned.

        No check is made to ensure that a directory with this name actually
        exists; but see **exists** ().

        **See also** **path** (), **filePath** (), **absolutePath** (), and
        **absoluteFilePath** ().
        """
        ...

    def canonicalPath(self) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#canonicalPath

        **QString QDir::canonicalPath() const**

        Returns the canonical path, i.e. a path without symbolic links or
        redundant "." or ".." elements.

        On systems that do not have symbolic links this function will always
        return the same string that **absolutePath** () returns. If the
        canonical path does not exist (normally due to dangling symbolic links)
        canonicalPath() returns an empty string.

        Example:

        **QString**  bin = "/local/bin";         // where /local/bin is a
        symlink to /usr/bin
            **QDir**  binDir(bin);
            **QString**
        canonicalBin = binDir.canonicalPath();
            // canonicalBin now equals
        "/usr/bin"

            **QString**  ls = "/local/bin/ls";       // where ls
        is the executable "ls"
            **QDir**  lsDir(ls);
            **QString**
        canonicalLs = lsDir.canonicalPath();
            // canonicalLS now equals
        "/usr/bin/ls".

        **See also** **path** (), **absolutePath** (), **exists** (),
        **cleanPath** (), **dirName** (), and **absoluteFilePath** ().
        """
        ...

    def absolutePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#absolutePath

        **QString QDir::absolutePath() const**

        Returns the absolute path (a path that starts with "/" or with a drive
        specification), which may contain symbolic links, but never contains
        redundant ".", ".." or multiple separators.

        **See also** **setPath** (), **canonicalPath** (), **exists** (),
        **cleanPath** (), **dirName** (), and **absoluteFilePath** ().
        """
        ...

    def path(self) -> str:
        """
        https://doc.qt.io/qt-6/qdir.html#path

        **QString QDir::path() const**

        Returns the path. This may contain symbolic links, but never contains
        redundant ".", ".." or multiple separators.

        The returned path can be either absolute or relative (see **setPath**
        ()).

        **See also** **setPath** (), **absolutePath** (), **exists** (),
        **cleanPath** (), **dirName** (), **absoluteFilePath** (),
        **toNativeSeparators** (), and **makeAbsolute** ().
        """
        ...

    def setPath(self, path: str) -> None:
        """
        https://doc.qt.io/qt-6/qdir.html#setPath

        **void QDir::setPath(const QString & path )**

        Sets the path of the directory to **path**. The path is cleaned of
        redundant ".", ".." and of multiple separators. No check is made to see
        whether a directory with this path actually exists; but you can check
        for yourself using **exists** ().

        The path can be either absolute or relative. Absolute paths begin with
        the directory separator "/" (optionally preceded by a drive
        specification under Windows). Relative file names begin with a directory
        name or a file name and specify a path relative to the current
        directory. An example of an absolute path is the string "/tmp/quartz", a
        relative path might look like "src/fatlib".

        **See also** **path** (), **absolutePath** (), **exists** (),
        **cleanPath** (), **dirName** (), **absoluteFilePath** (),
        **isRelative** (), and **makeAbsolute** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6.QtDBus import *


class QDBusPendingCall(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbuspendingcall.html

    **Detailed Description**

    A QDBusPendingCall object is a reference to a method call that was sent over
    D-Bus without waiting for a reply. QDBusPendingCall is an opaque type, meant
    to be used as a handle for a pending reply.

    In most programs, the QDBusPendingCall class will not be used directly. It
    can be safely replaced with the template-based **QDBusPendingReply** , in
    order to access the contents of the reply or wait for it to be complete.

    The **QDBusPendingCallWatcher**  class allows one to connect to a signal
    that will indicate when the reply has arrived or if the call has timed out.
    It also provides the **QDBusPendingCallWatcher::waitForFinished** () method
    which will suspend the execution of the program until the reply has arrived.

    **Note:** If you create a copy of a QDBusPendingCall object, all information
    will be shared among the many copies. Therefore, QDBusPendingCall is an
    explicitly-shared object and does not provide a method of detaching the
    copies (since they refer to the same pending call)

    **See also** **QDBusPendingReply**  and **QDBusPendingCallWatcher** .
    """

    def __init__(self, other: "QDBusPendingCall") -> None:
        """
        https://doc.qt.io/qt-6/qdbuspendingcall.html#QDBusPendingCall

        **QDBusPendingCall::QDBusPendingCall(const QDBusPendingCall & other )**

        Creates a copy of the **other** pending asynchronous call. Note that
        both objects will refer to the same pending call.
        """
        ...

    def swap(self, other: "QDBusPendingCall") -> None:
        """
        https://doc.qt.io/qt-6/qdbuspendingcall.html#swap

        **[since 5.0] void QDBusPendingCall::swap(QDBusPendingCall & other )**

        Swaps this pending call instance with **other**. This function is very
        fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    @staticmethod
    def fromCompletedCall(message: QDBusMessage) -> "QDBusPendingCall":
        """
        https://doc.qt.io/qt-6/qdbuspendingcall.html#fromCompletedCall

        **[static] QDBusPendingCall QDBusPendingCall::fromCompletedCall(const
        QDBusMessage & msg )**

        Creates a **QDBusPendingCall**  object based on the message **msg**. The
        message must be of type **QDBusMessage::ErrorMessage**  or
        **QDBusMessage::ReplyMessage**  (that is, a message that is typical of a
        completed call).

        This function is useful for code that requires simulating a pending
        call, but that has already finished.

        **See also** **fromError** ().
        """
        ...

    @staticmethod
    def fromError(error: QDBusError) -> "QDBusPendingCall":
        """
        https://doc.qt.io/qt-6/qdbuspendingcall.html#fromError

        **[static] QDBusPendingCall QDBusPendingCall::fromError(const QDBusError
        & error )**

        Creates a **QDBusPendingCall**  object based on the error condition
        **error**. The resulting pending call object will be in the "finished"
        state and **QDBusPendingReply** <Types...>::isError() will return true.

        **See also** **fromCompletedCall** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QItemEditorCreatorBase(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qitemeditorcreatorbase.html

    **Detailed Description**

    QItemEditorCreatorBase objects are specialized widget factories that provide
    editor widgets for one particular **QVariant**  data type. They are used by
    **QItemEditorFactory**  to create editors for **QStyledItemDelegate** s.
    Creator bases must be registered with **QItemEditorFactory::registerEditor**
    ().

    An editor should provide a user property for the data it edits.
    QItemDelagates can then access the property using Qt's **meta-object
    system**  to set and retrieve the editing data. A property is set as the
    user property with the USER keyword:

    Q_PROPERTY(**QColor**  color READ color WRITE setColor USER true)

    If the editor does not provide a user property, it must return the name of
    the property from **valuePropertyName** (); delegates will then use the name
    to access the property. If a user property exists, item delegates will not
    call **valuePropertyName** ().

    **QStandardItemEditorCreator**  is a convenience template class that can be
    used to register widgets without the need to subclass
    QItemEditorCreatorBase.

    **See also** **QStandardItemEditorCreator** , **QItemEditorFactory** ,
    **Model/View Programming** , and **Color Editor Factory Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QItemEditorCreatorBase") -> None:
        ...

    def valuePropertyName(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qitemeditorcreatorbase.html#valuePropertyName

        **[pure virtual] QByteArray QItemEditorCreatorBase::valuePropertyName()
        const**

        Returns the name of the property used to get and set values in the
        creator's editor widgets.

        When implementing this function in subclasses, you must ensure that the
        editor widget's property specified by this function can accept the type
        the creator is registered for. For example, a creator which constructs
        **QCheckBox**  widgets to edit boolean values would return the
        **checkable**  property name from this function, and must be registered
        in the item editor factory for the **QMetaType::Bool**  type.

        Note: Since Qt 4.2 the item delegates query the user property of
        widgets, and only call this function if the widget has no user property.
        You can override this behavior by reimplementing
        **QAbstractItemDelegate::setModelData** () and
        **QAbstractItemDelegate::setEditorData** ().

        **See also** **QMetaObject::userProperty** () and
        **QItemEditorFactory::registerEditor** ().
        """
        ...

    def createWidget(self, parent: QWidget) -> QWidget:
        """
        https://doc.qt.io/qt-6/qitemeditorcreatorbase.html#createWidget

        **[pure virtual] QWidget *QItemEditorCreatorBase::createWidget(QWidget *
        parent ) const**

        Returns an editor widget with the given **parent**.

        When implementing this function in subclasses of this class, you must
        construct and return new editor widgets with the parent widget
        specified.
        """
        ...
